# Standard Python libraries
from __future__ import (absolute_import, print_function,
                        division, unicode_literals)

__all__ = ['atomic_number', 'atomic_symbol', 'atomic_mass']

# List of all atomic symbols in order
atomic_symbols = ["H", "He", "Li", "Be", "B", "C", "N", "O", "F", "Ne", "Na", "Mg",
                 "Al", "Si", "P", "S", "Cl", "Ar", "K", "Ca", "Sc", "Ti", "V", 
                 "Cr", "Mn", "Fe", "Co", "Ni", "Cu", "Zn", "Ga", "Ge", "As", "Se",
                 "Br", "Kr", "Rb", "Sr", "Y", "Zr", "Nb", "Mo", "Tc", "Ru", "Rh",
                 "Pd", "Ag", "Cd", "In", "Sn", "Sb", "Te", "I", "Xe", "Cs", "Ba",
                 "La", "Ce", "Pr", "Nd", "Pm", "Sm", "Eu", "Gd", "Tb", "Dy", "Ho",
                 "Er", "Tm", "Yb", "Lu", "Hf", "Ta", "W", "Re", "Os", "Ir", "Pt",
                 "Au", "Hg", "Tl", "Pb", "Bi", "Po", "At", "Rn", "Fr", "Ra", "Ac",
                 "Th", "Pa", "U", "Np", "Pu", "Am", "Cm", "Bk", "Cf", "Es", "Fm",
                 "Md", "No", "Lr", "Rf", "Db", "Sg", "Bh", "Hs", "Mt", "Ds", "Rg",
                 "Cn", "Uut", "Fl", "Uup", "Lv", "Uus", "Uuo"]

# Dictionary of all standard atomic weights of elements and relative atomic
# masses of isotopes in a.m.u.s
atomic_masses = {
    "H": 1.007975, 
    "He": 4.002602, 
    "Li": 6.967499999999999, 
    "Be": 9.0121831, 
    "B": 10.8135, 
    "C": 12.0106, 
    "N": 14.006855, 
    "O": 15.9994, 
    "F": 18.998403163, 
    "Ne": 20.1797, 
    "Na": 22.98976928, 
    "Mg": 24.3055, 
    "Al": 26.9815385, 
    "Si": 28.085, 
    "P": 30.973761998, 
    "S": 32.067499999999995, 
    "Cl": 35.451499999999996, 
    "Ar": 39.948, 
    "K": 39.0983, 
    "Ca": 40.078, 
    "Sc": 44.955908, 
    "Ti": 47.867, 
    "V": 50.9415, 
    "Cr": 51.9961, 
    "Mn": 54.938044, 
    "Fe": 55.845, 
    "Co": 58.933194, 
    "Ni": 58.6934, 
    "Cu": 63.546, 
    "Zn": 65.38, 
    "Ga": 69.723, 
    "Ge": 72.63, 
    "As": 74.921595, 
    "Se": 78.971, 
    "Br": 79.904, 
    "Kr": 83.798, 
    "Rb": 85.4678, 
    "Sr": 87.62, 
    "Y": 88.90584, 
    "Zr": 91.224, 
    "Nb": 92.90637, 
    "Mo": 95.95, 
    "Tc": 98.0, 
    "Ru": 101.07, 
    "Rh": 102.9055, 
    "Pd": 106.42, 
    "Ag": 107.8682, 
    "Cd": 112.414, 
    "In": 114.818, 
    "Sn": 118.71, 
    "Sb": 121.76, 
    "Te": 127.6, 
    "I": 126.90447, 
    "Xe": 131.293, 
    "Cs": 132.90545196, 
    "Ba": 137.327, 
    "La": 138.90547, 
    "Ce": 140.116, 
    "Pr": 140.90766, 
    "Nd": 144.242, 
    "Pm": 145.0, 
    "Sm": 150.36, 
    "Eu": 151.964, 
    "Gd": 157.25, 
    "Tb": 158.92535, 
    "Dy": 162.5, 
    "Ho": 164.93033, 
    "Er": 167.259, 
    "Tm": 168.93422, 
    "Yb": 173.054, 
    "Lu": 174.9668, 
    "Hf": 178.49, 
    "Ta": 180.94788, 
    "W": 183.84, 
    "Re": 186.207, 
    "Os": 190.23, 
    "Ir": 192.217, 
    "Pt": 195.084, 
    "Au": 196.966569, 
    "Hg": 200.592, 
    "Tl": 204.3835, 
    "Pb": 207.2, 
    "Bi": 208.9804, 
    "Po": 209.0, 
    "At": 210.0, 
    "Rn": 222.0, 
    "Fr": 223.0, 
    "Ra": 226.0, 
    "Ac": 227.0, 
    "Th": 232.0377, 
    "Pa": 231.03588, 
    "U": 238.02891, 
    "Np": 237.0, 
    "Pu": 244.0, 
    "H-1": 1.00782503223, 
    "H-2": 2.01410177812, 
    "D": 2.01410177812, 
    "H-3": 3.0160492779, 
    "T": 3.0160492779, 
    "H-4": 4.02643, 
    "H-5": 5.035311, 
    "H-6": 6.04496, 
    "H-7": 7.0527, 
    "He-3": 3.0160293201, 
    "He-4": 4.00260325413, 
    "He-5": 5.012057, 
    "He-6": 6.018885891, 
    "He-7": 7.0279907, 
    "He-8": 8.03393439, 
    "He-9": 9.043946, 
    "He-10": 10.05279, 
    "Li-3": 3.0308, 
    "Li-4": 4.02719, 
    "Li-5": 5.012538, 
    "Li-6": 6.0151228874, 
    "Li-7": 7.0160034366, 
    "Li-8": 8.022486246, 
    "Li-9": 9.02679019, 
    "Li-10": 10.035483, 
    "Li-11": 11.04372358, 
    "Li-12": 12.052517, 
    "Li-13": 13.06263, 
    "Be-5": 5.0399, 
    "Be-6": 6.0197264, 
    "Be-7": 7.016928717, 
    "Be-8": 8.005305102, 
    "Be-9": 9.012183065, 
    "Be-10": 10.013534695, 
    "Be-11": 11.02166108, 
    "Be-12": 12.0269221, 
    "Be-13": 13.036135, 
    "Be-14": 14.04289, 
    "Be-15": 15.05342, 
    "Be-16": 16.06167, 
    "B-6": 6.0508, 
    "B-7": 7.029712, 
    "B-8": 8.0246073, 
    "B-9": 9.01332965, 
    "B-10": 10.01293695, 
    "B-11": 11.00930536, 
    "B-12": 12.0143527, 
    "B-13": 13.0177802, 
    "B-14": 14.025404, 
    "B-15": 15.031088, 
    "B-16": 16.039842, 
    "B-17": 17.04699, 
    "B-18": 18.05566, 
    "B-19": 19.0631, 
    "B-20": 20.07207, 
    "B-21": 21.08129, 
    "C-8": 8.037643, 
    "C-9": 9.0310372, 
    "C-10": 10.01685331, 
    "C-11": 11.0114336, 
    "C-12": 12.0, 
    "C-13": 13.00335483507, 
    "C-14": 14.0032419884, 
    "C-15": 15.01059926, 
    "C-16": 16.0147013, 
    "C-17": 17.022577, 
    "C-18": 18.026751, 
    "C-19": 19.0348, 
    "C-20": 20.04032, 
    "C-21": 21.049, 
    "C-22": 22.05753, 
    "C-23": 23.0689, 
    "N-10": 10.04165, 
    "N-11": 11.026091, 
    "N-12": 12.0186132, 
    "N-13": 13.00573861, 
    "N-14": 14.00307400443, 
    "N-15": 15.00010889888, 
    "N-16": 16.0061019, 
    "N-17": 17.008449, 
    "N-18": 18.014078, 
    "N-19": 19.017022, 
    "N-20": 20.023366, 
    "N-21": 21.02711, 
    "N-22": 22.03439, 
    "N-23": 23.04114, 
    "N-24": 24.05039, 
    "N-25": 25.0601, 
    "O-12": 12.034262, 
    "O-13": 13.024815, 
    "O-14": 14.00859636, 
    "O-15": 15.00306562, 
    "O-16": 15.99491461957, 
    "O-17": 16.9991317565, 
    "O-18": 17.99915961286, 
    "O-19": 19.003578, 
    "O-20": 20.00407535, 
    "O-21": 21.008655, 
    "O-22": 22.009966, 
    "O-23": 23.015696, 
    "O-24": 24.01986, 
    "O-25": 25.02936, 
    "O-26": 26.03729, 
    "O-27": 27.04772, 
    "O-28": 28.05591, 
    "F-14": 14.034315, 
    "F-15": 15.018043, 
    "F-16": 16.0114657, 
    "F-17": 17.00209524, 
    "F-18": 18.00093733, 
    "F-19": 18.99840316273, 
    "F-20": 19.999981252, 
    "F-21": 20.9999489, 
    "F-22": 22.002999, 
    "F-23": 23.003557, 
    "F-24": 24.008115, 
    "F-25": 25.012199, 
    "F-26": 26.020038, 
    "F-27": 27.02644, 
    "F-28": 28.03534, 
    "F-29": 29.04254, 
    "F-30": 30.05165, 
    "F-31": 31.05971, 
    "Ne-16": 16.02575, 
    "Ne-17": 17.01771396, 
    "Ne-18": 18.0057087, 
    "Ne-19": 19.00188091, 
    "Ne-20": 19.9924401762, 
    "Ne-21": 20.993846685, 
    "Ne-22": 21.991385114, 
    "Ne-23": 22.99446691, 
    "Ne-24": 23.99361065, 
    "Ne-25": 24.997789, 
    "Ne-26": 26.000515, 
    "Ne-27": 27.007553, 
    "Ne-28": 28.01212, 
    "Ne-29": 29.01975, 
    "Ne-30": 30.02473, 
    "Ne-31": 31.0331, 
    "Ne-32": 32.03972, 
    "Ne-33": 33.04938, 
    "Ne-34": 34.05673, 
    "Na-18": 18.02688, 
    "Na-19": 19.01388, 
    "Na-20": 20.0073544, 
    "Na-21": 20.99765469, 
    "Na-22": 21.99443741, 
    "Na-23": 22.989769282, 
    "Na-24": 23.99096295, 
    "Na-25": 24.989954, 
    "Na-26": 25.9926346, 
    "Na-27": 26.9940765, 
    "Na-28": 27.998939, 
    "Na-29": 29.0028771, 
    "Na-30": 30.0090979, 
    "Na-31": 31.013163, 
    "Na-32": 32.02019, 
    "Na-33": 33.02573, 
    "Na-34": 34.03359, 
    "Na-35": 35.04062, 
    "Na-36": 36.04929, 
    "Na-37": 37.05705, 
    "Mg-19": 19.034169, 
    "Mg-20": 20.01885, 
    "Mg-21": 21.011716, 
    "Mg-22": 21.99957065, 
    "Mg-23": 22.99412421, 
    "Mg-24": 23.985041697, 
    "Mg-25": 24.985836976, 
    "Mg-26": 25.982592968, 
    "Mg-27": 26.984340624, 
    "Mg-28": 27.9838767, 
    "Mg-29": 28.988617, 
    "Mg-30": 29.9904629, 
    "Mg-31": 30.996648, 
    "Mg-32": 31.9991102, 
    "Mg-33": 33.0053271, 
    "Mg-34": 34.008935, 
    "Mg-35": 35.01679, 
    "Mg-36": 36.02188, 
    "Mg-37": 37.03037, 
    "Mg-38": 38.03658, 
    "Mg-39": 39.04538, 
    "Mg-40": 40.05218, 
    "Al-21": 21.02897, 
    "Al-22": 22.01954, 
    "Al-23": 23.00724435, 
    "Al-24": 23.9999489, 
    "Al-25": 24.9904281, 
    "Al-26": 25.986891904, 
    "Al-27": 26.98153853, 
    "Al-28": 27.98191021, 
    "Al-29": 28.9804565, 
    "Al-30": 29.98296, 
    "Al-31": 30.983945, 
    "Al-32": 31.988085, 
    "Al-33": 32.990909, 
    "Al-34": 33.996705, 
    "Al-35": 34.999764, 
    "Al-36": 36.00639, 
    "Al-37": 37.01053, 
    "Al-38": 38.0174, 
    "Al-39": 39.02254, 
    "Al-40": 40.03003, 
    "Al-41": 41.03638, 
    "Al-42": 42.04384, 
    "Al-43": 43.05147, 
    "Si-22": 22.03579, 
    "Si-23": 23.02544, 
    "Si-24": 24.011535, 
    "Si-25": 25.004109, 
    "Si-26": 25.99233384, 
    "Si-27": 26.98670481, 
    "Si-28": 27.97692653465, 
    "Si-29": 28.9764946649, 
    "Si-30": 29.973770136, 
    "Si-31": 30.975363194, 
    "Si-32": 31.97415154, 
    "Si-33": 32.97797696, 
    "Si-34": 33.978576, 
    "Si-35": 34.984583, 
    "Si-36": 35.986695, 
    "Si-37": 36.992921, 
    "Si-38": 37.995523, 
    "Si-39": 39.002491, 
    "Si-40": 40.00583, 
    "Si-41": 41.01301, 
    "Si-42": 42.01778, 
    "Si-43": 43.0248, 
    "Si-44": 44.03061, 
    "Si-45": 45.03995, 
    "P-24": 24.03577, 
    "P-25": 25.02119, 
    "P-26": 26.01178, 
    "P-27": 26.999224, 
    "P-28": 27.9923266, 
    "P-29": 28.98180079, 
    "P-30": 29.97831375, 
    "P-31": 30.97376199842, 
    "P-32": 31.973907643, 
    "P-33": 32.9717257, 
    "P-34": 33.97364589, 
    "P-35": 34.9733141, 
    "P-36": 35.97826, 
    "P-37": 36.979607, 
    "P-38": 37.984252, 
    "P-39": 38.986227, 
    "P-40": 39.99133, 
    "P-41": 40.994654, 
    "P-42": 42.00108, 
    "P-43": 43.00502, 
    "P-44": 44.01121, 
    "P-45": 45.01645, 
    "P-46": 46.02446, 
    "P-47": 47.03139, 
    "S-26": 26.02907, 
    "S-27": 27.01828, 
    "S-28": 28.00437, 
    "S-29": 28.996611, 
    "S-30": 29.98490703, 
    "S-31": 30.97955701, 
    "S-32": 31.9720711744, 
    "S-33": 32.9714589098, 
    "S-34": 33.967867004, 
    "S-35": 34.96903231, 
    "S-36": 35.96708071, 
    "S-37": 36.97112551, 
    "S-38": 37.9711633, 
    "S-39": 38.975134, 
    "S-40": 39.9754826, 
    "S-41": 40.9795935, 
    "S-42": 41.9810651, 
    "S-43": 42.9869076, 
    "S-44": 43.9901188, 
    "S-45": 44.99572, 
    "S-46": 46.00004, 
    "S-47": 47.00795, 
    "S-48": 48.0137, 
    "S-49": 49.02276, 
    "Cl-28": 28.02954, 
    "Cl-29": 29.01478, 
    "Cl-30": 30.00477, 
    "Cl-31": 30.992414, 
    "Cl-32": 31.98568464, 
    "Cl-33": 32.97745199, 
    "Cl-34": 33.973762485, 
    "Cl-35": 34.968852682, 
    "Cl-36": 35.968306809, 
    "Cl-37": 36.965902602, 
    "Cl-38": 37.96801044, 
    "Cl-39": 38.9680082, 
    "Cl-40": 39.970415, 
    "Cl-41": 40.970685, 
    "Cl-42": 41.97325, 
    "Cl-43": 42.97389, 
    "Cl-44": 43.97787, 
    "Cl-45": 44.98029, 
    "Cl-46": 45.98517, 
    "Cl-47": 46.98916, 
    "Cl-48": 47.99564, 
    "Cl-49": 49.00123, 
    "Cl-50": 50.00905, 
    "Cl-51": 51.01554, 
    "Ar-30": 30.02307, 
    "Ar-31": 31.01212, 
    "Ar-32": 31.9976378, 
    "Ar-33": 32.98992555, 
    "Ar-34": 33.98027009, 
    "Ar-35": 34.97525759, 
    "Ar-36": 35.967545105, 
    "Ar-37": 36.96677633, 
    "Ar-38": 37.96273211, 
    "Ar-39": 38.964313, 
    "Ar-40": 39.9623831237, 
    "Ar-41": 40.96450057, 
    "Ar-42": 41.9630457, 
    "Ar-43": 42.9656361, 
    "Ar-44": 43.9649238, 
    "Ar-45": 44.96803973, 
    "Ar-46": 45.968083, 
    "Ar-47": 46.972935, 
    "Ar-48": 47.97591, 
    "Ar-49": 48.9819, 
    "Ar-50": 49.98613, 
    "Ar-51": 50.9937, 
    "Ar-52": 51.99896, 
    "Ar-53": 53.00729, 
    "K-32": 32.02265, 
    "K-33": 33.00756, 
    "K-34": 33.99869, 
    "K-35": 34.98800541, 
    "K-36": 35.98130201, 
    "K-37": 36.97337589, 
    "K-38": 37.96908112, 
    "K-39": 38.9637064864, 
    "K-40": 39.963998166, 
    "K-41": 40.9618252579, 
    "K-42": 41.96240231, 
    "K-43": 42.9607347, 
    "K-44": 43.96158699, 
    "K-45": 44.96069149, 
    "K-46": 45.96198159, 
    "K-47": 46.9616616, 
    "K-48": 47.96534119, 
    "K-49": 48.96821075, 
    "K-50": 49.97238, 
    "K-51": 50.975828, 
    "K-52": 51.98224, 
    "K-53": 52.98746, 
    "K-54": 53.99463, 
    "K-55": 55.00076, 
    "K-56": 56.00851, 
    "Ca-34": 34.01487, 
    "Ca-35": 35.00514, 
    "Ca-36": 35.993074, 
    "Ca-37": 36.98589785, 
    "Ca-38": 37.97631922, 
    "Ca-39": 38.97071081, 
    "Ca-40": 39.962590863, 
    "Ca-41": 40.96227792, 
    "Ca-42": 41.95861783, 
    "Ca-43": 42.95876644, 
    "Ca-44": 43.95548156, 
    "Ca-45": 44.95618635, 
    "Ca-46": 45.953689, 
    "Ca-47": 46.9545424, 
    "Ca-48": 47.95252276, 
    "Ca-49": 48.95566274, 
    "Ca-50": 49.9574992, 
    "Ca-51": 50.960989, 
    "Ca-52": 51.963217, 
    "Ca-53": 52.96945, 
    "Ca-54": 53.9734, 
    "Ca-55": 54.9803, 
    "Ca-56": 55.98508, 
    "Ca-57": 56.99262, 
    "Ca-58": 57.99794, 
    "Sc-36": 36.01648, 
    "Sc-37": 37.00374, 
    "Sc-38": 37.99512, 
    "Sc-39": 38.984785, 
    "Sc-40": 39.9779673, 
    "Sc-41": 40.969251105, 
    "Sc-42": 41.96551653, 
    "Sc-43": 42.9611505, 
    "Sc-44": 43.9594029, 
    "Sc-45": 44.95590828, 
    "Sc-46": 45.95516826, 
    "Sc-47": 46.9524037, 
    "Sc-48": 47.9522236, 
    "Sc-49": 48.9500146, 
    "Sc-50": 49.952176, 
    "Sc-51": 50.953592, 
    "Sc-52": 51.95688, 
    "Sc-53": 52.95909, 
    "Sc-54": 53.96393, 
    "Sc-55": 54.96782, 
    "Sc-56": 55.97345, 
    "Sc-57": 56.97777, 
    "Sc-58": 57.98403, 
    "Sc-59": 58.98894, 
    "Sc-60": 59.99565, 
    "Sc-61": 61.001, 
    "Ti-38": 38.01145, 
    "Ti-39": 39.00236, 
    "Ti-40": 39.9905, 
    "Ti-41": 40.983148, 
    "Ti-42": 41.97304903, 
    "Ti-43": 42.9685225, 
    "Ti-44": 43.95968995, 
    "Ti-45": 44.95812198, 
    "Ti-46": 45.95262772, 
    "Ti-47": 46.95175879, 
    "Ti-48": 47.94794198, 
    "Ti-49": 48.94786568, 
    "Ti-50": 49.94478689, 
    "Ti-51": 50.94661065, 
    "Ti-52": 51.946893, 
    "Ti-53": 52.94973, 
    "Ti-54": 53.95105, 
    "Ti-55": 54.95527, 
    "Ti-56": 55.95791, 
    "Ti-57": 56.96364, 
    "Ti-58": 57.9666, 
    "Ti-59": 58.97247, 
    "Ti-60": 59.97603, 
    "Ti-61": 60.98245, 
    "Ti-62": 61.98651, 
    "Ti-63": 62.99375, 
    "V-40": 40.01276, 
    "V-41": 41.00021, 
    "V-42": 41.99182, 
    "V-43": 42.980766, 
    "V-44": 43.97411, 
    "V-45": 44.9657748, 
    "V-46": 45.96019878, 
    "V-47": 46.95490491, 
    "V-48": 47.9522522, 
    "V-49": 48.9485118, 
    "V-50": 49.94715601, 
    "V-51": 50.94395704, 
    "V-52": 51.94477301, 
    "V-53": 52.9443367, 
    "V-54": 53.946439, 
    "V-55": 54.94724, 
    "V-56": 55.95048, 
    "V-57": 56.95252, 
    "V-58": 57.95672, 
    "V-59": 58.95939, 
    "V-60": 59.96431, 
    "V-61": 60.96725, 
    "V-62": 61.97265, 
    "V-63": 62.97639, 
    "V-64": 63.98264, 
    "V-65": 64.9875, 
    "V-66": 65.99398, 
    "Cr-42": 42.0067, 
    "Cr-43": 42.99753, 
    "Cr-44": 43.98536, 
    "Cr-45": 44.97905, 
    "Cr-46": 45.968359, 
    "Cr-47": 46.9628974, 
    "Cr-48": 47.9540291, 
    "Cr-49": 48.9513333, 
    "Cr-50": 49.94604183, 
    "Cr-51": 50.94476502, 
    "Cr-52": 51.94050623, 
    "Cr-53": 52.94064815, 
    "Cr-54": 53.93887916, 
    "Cr-55": 54.94083843, 
    "Cr-56": 55.9406531, 
    "Cr-57": 56.943613, 
    "Cr-58": 57.94435, 
    "Cr-59": 58.94859, 
    "Cr-60": 59.95008, 
    "Cr-61": 60.95442, 
    "Cr-62": 61.9561, 
    "Cr-63": 62.96165, 
    "Cr-64": 63.96408, 
    "Cr-65": 64.96996, 
    "Cr-66": 65.97366, 
    "Cr-67": 66.98016, 
    "Cr-68": 67.98403, 
    "Mn-44": 44.00715, 
    "Mn-45": 44.99449, 
    "Mn-46": 45.98609, 
    "Mn-47": 46.975775, 
    "Mn-48": 47.96852, 
    "Mn-49": 48.959595, 
    "Mn-50": 49.95423778, 
    "Mn-51": 50.94820847, 
    "Mn-52": 51.9455639, 
    "Mn-53": 52.94128889, 
    "Mn-54": 53.9403576, 
    "Mn-55": 54.93804391, 
    "Mn-56": 55.93890369, 
    "Mn-57": 56.9382861, 
    "Mn-58": 57.9400666, 
    "Mn-59": 58.9403911, 
    "Mn-60": 59.9431366, 
    "Mn-61": 60.9444525, 
    "Mn-62": 61.94795, 
    "Mn-63": 62.9496647, 
    "Mn-64": 63.9538494, 
    "Mn-65": 64.9560198, 
    "Mn-66": 65.960547, 
    "Mn-67": 66.96424, 
    "Mn-68": 67.96962, 
    "Mn-69": 68.97366, 
    "Mn-70": 69.97937, 
    "Mn-71": 70.98368, 
    "Fe-45": 45.01442, 
    "Fe-46": 46.00063, 
    "Fe-47": 46.99185, 
    "Fe-48": 47.98023, 
    "Fe-49": 48.973429, 
    "Fe-50": 49.962975, 
    "Fe-51": 50.956841, 
    "Fe-52": 51.9481131, 
    "Fe-53": 52.9453064, 
    "Fe-54": 53.93960899, 
    "Fe-55": 54.93829199, 
    "Fe-56": 55.93493633, 
    "Fe-57": 56.93539284, 
    "Fe-58": 57.93327443, 
    "Fe-59": 58.93487434, 
    "Fe-60": 59.9340711, 
    "Fe-61": 60.9367462, 
    "Fe-62": 61.9367918, 
    "Fe-63": 62.9402727, 
    "Fe-64": 63.9409878, 
    "Fe-65": 64.9450115, 
    "Fe-66": 65.94625, 
    "Fe-67": 66.95054, 
    "Fe-68": 67.95295, 
    "Fe-69": 68.95807, 
    "Fe-70": 69.96102, 
    "Fe-71": 70.96672, 
    "Fe-72": 71.96983, 
    "Fe-73": 72.97572, 
    "Fe-74": 73.97935, 
    "Co-47": 47.01057, 
    "Co-48": 48.00093, 
    "Co-49": 48.98891, 
    "Co-50": 49.98091, 
    "Co-51": 50.970647, 
    "Co-52": 51.96351, 
    "Co-53": 52.9542041, 
    "Co-54": 53.94845987, 
    "Co-55": 54.9419972, 
    "Co-56": 55.9398388, 
    "Co-57": 56.93629057, 
    "Co-58": 57.9357521, 
    "Co-59": 58.93319429, 
    "Co-60": 59.9338163, 
    "Co-61": 60.93247662, 
    "Co-62": 61.934059, 
    "Co-63": 62.9336, 
    "Co-64": 63.935811, 
    "Co-65": 64.9364621, 
    "Co-66": 65.939443, 
    "Co-67": 66.9406096, 
    "Co-68": 67.94426, 
    "Co-69": 68.94614, 
    "Co-70": 69.94963, 
    "Co-71": 70.95237, 
    "Co-72": 71.95729, 
    "Co-73": 72.96039, 
    "Co-74": 73.96515, 
    "Co-75": 74.96876, 
    "Co-76": 75.97413, 
    "Ni-48": 48.01769, 
    "Ni-49": 49.0077, 
    "Ni-50": 49.99474, 
    "Ni-51": 50.98611, 
    "Ni-52": 51.9748, 
    "Ni-53": 52.96819, 
    "Ni-54": 53.957892, 
    "Ni-55": 54.95133063, 
    "Ni-56": 55.94212855, 
    "Ni-57": 56.93979218, 
    "Ni-58": 57.93534241, 
    "Ni-59": 58.9343462, 
    "Ni-60": 59.93078588, 
    "Ni-61": 60.93105557, 
    "Ni-62": 61.92834537, 
    "Ni-63": 62.92966963, 
    "Ni-64": 63.92796682, 
    "Ni-65": 64.93008517, 
    "Ni-66": 65.9291393, 
    "Ni-67": 66.9315694, 
    "Ni-68": 67.9318688, 
    "Ni-69": 68.9356103, 
    "Ni-70": 69.9364313, 
    "Ni-71": 70.940519, 
    "Ni-72": 71.9417859, 
    "Ni-73": 72.9462067, 
    "Ni-74": 73.94798, 
    "Ni-75": 74.9525, 
    "Ni-76": 75.95533, 
    "Ni-77": 76.96055, 
    "Ni-78": 77.96336, 
    "Ni-79": 78.97025, 
    "Cu-52": 51.99671, 
    "Cu-53": 52.98459, 
    "Cu-54": 53.97666, 
    "Cu-55": 54.96604, 
    "Cu-56": 55.95895, 
    "Cu-57": 56.9492125, 
    "Cu-58": 57.94453305, 
    "Cu-59": 58.93949748, 
    "Cu-60": 59.9373645, 
    "Cu-61": 60.9334576, 
    "Cu-62": 61.93259541, 
    "Cu-63": 62.92959772, 
    "Cu-64": 63.92976434, 
    "Cu-65": 64.9277897, 
    "Cu-66": 65.92886903, 
    "Cu-67": 66.9277303, 
    "Cu-68": 67.9296109, 
    "Cu-69": 68.9294293, 
    "Cu-70": 69.9323921, 
    "Cu-71": 70.9326768, 
    "Cu-72": 71.9358203, 
    "Cu-73": 72.9366744, 
    "Cu-74": 73.9398749, 
    "Cu-75": 74.9415226, 
    "Cu-76": 75.945275, 
    "Cu-77": 76.94792, 
    "Cu-78": 77.95223, 
    "Cu-79": 78.95502, 
    "Cu-80": 79.96089, 
    "Cu-81": 80.96587, 
    "Cu-82": 81.97244, 
    "Zn-54": 53.99204, 
    "Zn-55": 54.98398, 
    "Zn-56": 55.97254, 
    "Zn-57": 56.96506, 
    "Zn-58": 57.954591, 
    "Zn-59": 58.94931266, 
    "Zn-60": 59.9418421, 
    "Zn-61": 60.939507, 
    "Zn-62": 61.93433397, 
    "Zn-63": 62.9332115, 
    "Zn-64": 63.92914201, 
    "Zn-65": 64.92924077, 
    "Zn-66": 65.92603381, 
    "Zn-67": 66.92712775, 
    "Zn-68": 67.92484455, 
    "Zn-69": 68.9265507, 
    "Zn-70": 69.9253192, 
    "Zn-71": 70.9277196, 
    "Zn-72": 71.9268428, 
    "Zn-73": 72.9295826, 
    "Zn-74": 73.9294073, 
    "Zn-75": 74.9328402, 
    "Zn-76": 75.933115, 
    "Zn-77": 76.9368872, 
    "Zn-78": 77.9382892, 
    "Zn-79": 78.9426381, 
    "Zn-80": 79.9445529, 
    "Zn-81": 80.9504026, 
    "Zn-82": 81.95426, 
    "Zn-83": 82.96056, 
    "Zn-84": 83.96521, 
    "Zn-85": 84.97226, 
    "Ga-56": 55.99536, 
    "Ga-57": 56.9832, 
    "Ga-58": 57.97478, 
    "Ga-59": 58.96353, 
    "Ga-60": 59.95729, 
    "Ga-61": 60.949399, 
    "Ga-62": 61.94419025, 
    "Ga-63": 62.9392942, 
    "Ga-64": 63.9368404, 
    "Ga-65": 64.93273459, 
    "Ga-66": 65.9315894, 
    "Ga-67": 66.9282025, 
    "Ga-68": 67.9279805, 
    "Ga-69": 68.9255735, 
    "Ga-70": 69.9260219, 
    "Ga-71": 70.92470258, 
    "Ga-72": 71.92636747, 
    "Ga-73": 72.9251747, 
    "Ga-74": 73.9269457, 
    "Ga-75": 74.9265002, 
    "Ga-76": 75.9288276, 
    "Ga-77": 76.9291543, 
    "Ga-78": 77.9316088, 
    "Ga-79": 78.9328523, 
    "Ga-80": 79.9364208, 
    "Ga-81": 80.9381338, 
    "Ga-82": 81.9431765, 
    "Ga-83": 82.9471203, 
    "Ga-84": 83.95246, 
    "Ga-85": 84.95699, 
    "Ga-86": 85.96301, 
    "Ga-87": 86.96824, 
    "Ge-58": 57.99172, 
    "Ge-59": 58.98249, 
    "Ge-60": 59.97036, 
    "Ge-61": 60.96379, 
    "Ge-62": 61.95502, 
    "Ge-63": 62.949628, 
    "Ge-64": 63.9416899, 
    "Ge-65": 64.9393681, 
    "Ge-66": 65.9338621, 
    "Ge-67": 66.9327339, 
    "Ge-68": 67.9280953, 
    "Ge-69": 68.9279645, 
    "Ge-70": 69.92424875, 
    "Ge-71": 70.92495233, 
    "Ge-72": 71.922075826, 
    "Ge-73": 72.923458956, 
    "Ge-74": 73.921177761, 
    "Ge-75": 74.92285837, 
    "Ge-76": 75.921402726, 
    "Ge-77": 76.923549843, 
    "Ge-78": 77.9228529, 
    "Ge-79": 78.92536, 
    "Ge-80": 79.9253508, 
    "Ge-81": 80.9288329, 
    "Ge-82": 81.929774, 
    "Ge-83": 82.9345391, 
    "Ge-84": 83.9375751, 
    "Ge-85": 84.9429697, 
    "Ge-86": 85.94658, 
    "Ge-87": 86.95268, 
    "Ge-88": 87.95691, 
    "Ge-89": 88.96379, 
    "Ge-90": 89.96863, 
    "As-60": 59.99388, 
    "As-61": 60.98112, 
    "As-62": 61.97361, 
    "As-63": 62.9639, 
    "As-64": 63.95743, 
    "As-65": 64.949611, 
    "As-66": 65.9441488, 
    "As-67": 66.93925111, 
    "As-68": 67.9367741, 
    "As-69": 68.932246, 
    "As-70": 69.930926, 
    "As-71": 70.9271138, 
    "As-72": 71.9267523, 
    "As-73": 72.9238291, 
    "As-74": 73.9239286, 
    "As-75": 74.92159457, 
    "As-76": 75.92239202, 
    "As-77": 76.9206476, 
    "As-78": 77.921828, 
    "As-79": 78.9209484, 
    "As-80": 79.9224746, 
    "As-81": 80.9221323, 
    "As-82": 81.9247412, 
    "As-83": 82.9252069, 
    "As-84": 83.9293033, 
    "As-85": 84.9321637, 
    "As-86": 85.9367015, 
    "As-87": 86.9402917, 
    "As-88": 87.94555, 
    "As-89": 88.94976, 
    "As-90": 89.95563, 
    "As-91": 90.96039, 
    "As-92": 91.96674, 
    "Se-64": 63.97109, 
    "Se-65": 64.9644, 
    "Se-66": 65.95559, 
    "Se-67": 66.949994, 
    "Se-68": 67.94182524, 
    "Se-69": 68.9394148, 
    "Se-70": 69.9335155, 
    "Se-71": 70.9322094, 
    "Se-72": 71.9271405, 
    "Se-73": 72.9267549, 
    "Se-74": 73.922475934, 
    "Se-75": 74.92252287, 
    "Se-76": 75.919213704, 
    "Se-77": 76.919914154, 
    "Se-78": 77.91730928, 
    "Se-79": 78.91849929, 
    "Se-80": 79.9165218, 
    "Se-81": 80.917993, 
    "Se-82": 81.9166995, 
    "Se-83": 82.9191186, 
    "Se-84": 83.9184668, 
    "Se-85": 84.9222608, 
    "Se-86": 85.9243117, 
    "Se-87": 86.9286886, 
    "Se-88": 87.9314175, 
    "Se-89": 88.9366691, 
    "Se-90": 89.9401, 
    "Se-91": 90.94596, 
    "Se-92": 91.94984, 
    "Se-93": 92.95629, 
    "Se-94": 93.96049, 
    "Se-95": 94.9673, 
    "Br-67": 66.96465, 
    "Br-68": 67.95873, 
    "Br-69": 68.950497, 
    "Br-70": 69.944792, 
    "Br-71": 70.9393422, 
    "Br-72": 71.9365886, 
    "Br-73": 72.9316715, 
    "Br-74": 73.9299102, 
    "Br-75": 74.9258105, 
    "Br-76": 75.924542, 
    "Br-77": 76.9213792, 
    "Br-78": 77.9211459, 
    "Br-79": 78.9183376, 
    "Br-80": 79.9185298, 
    "Br-81": 80.9162897, 
    "Br-82": 81.9168032, 
    "Br-83": 82.9151756, 
    "Br-84": 83.916496, 
    "Br-85": 84.9156458, 
    "Br-86": 85.9188054, 
    "Br-87": 86.920674, 
    "Br-88": 87.9240833, 
    "Br-89": 88.9267046, 
    "Br-90": 89.9312928, 
    "Br-91": 90.9343986, 
    "Br-92": 91.9396316, 
    "Br-93": 92.94313, 
    "Br-94": 93.9489, 
    "Br-95": 94.95301, 
    "Br-96": 95.95903, 
    "Br-97": 96.96344, 
    "Br-98": 97.96946, 
    "Kr-69": 68.96518, 
    "Kr-70": 69.95604, 
    "Kr-71": 70.95027, 
    "Kr-72": 71.9420924, 
    "Kr-73": 72.9392892, 
    "Kr-74": 73.933084, 
    "Kr-75": 74.9309457, 
    "Kr-76": 75.9259103, 
    "Kr-77": 76.92467, 
    "Kr-78": 77.92036494, 
    "Kr-79": 78.9200829, 
    "Kr-80": 79.91637808, 
    "Kr-81": 80.9165912, 
    "Kr-82": 81.91348273, 
    "Kr-83": 82.91412716, 
    "Kr-84": 83.9114977282, 
    "Kr-85": 84.9125273, 
    "Kr-86": 85.9106106269, 
    "Kr-87": 86.91335476, 
    "Kr-88": 87.9144479, 
    "Kr-89": 88.9178355, 
    "Kr-90": 89.9195279, 
    "Kr-91": 90.9238063, 
    "Kr-92": 91.9261731, 
    "Kr-93": 92.9311472, 
    "Kr-94": 93.93414, 
    "Kr-95": 94.939711, 
    "Kr-96": 95.943017, 
    "Kr-97": 96.94909, 
    "Kr-98": 97.95243, 
    "Kr-99": 98.95839, 
    "Kr-100": 99.96237, 
    "Kr-101": 100.96873, 
    "Rb-71": 70.96532, 
    "Rb-72": 71.95908, 
    "Rb-73": 72.95053, 
    "Rb-74": 73.9442659, 
    "Rb-75": 74.9385732, 
    "Rb-76": 75.935073, 
    "Rb-77": 76.9304016, 
    "Rb-78": 77.9281419, 
    "Rb-79": 78.9239899, 
    "Rb-80": 79.9225164, 
    "Rb-81": 80.9189939, 
    "Rb-82": 81.918209, 
    "Rb-83": 82.9151142, 
    "Rb-84": 83.9143752, 
    "Rb-85": 84.9117897379, 
    "Rb-86": 85.91116743, 
    "Rb-87": 86.909180531, 
    "Rb-88": 87.91131559, 
    "Rb-89": 88.9122783, 
    "Rb-90": 89.9147985, 
    "Rb-91": 90.9165372, 
    "Rb-92": 91.9197284, 
    "Rb-93": 92.9220393, 
    "Rb-94": 93.9263948, 
    "Rb-95": 94.92926, 
    "Rb-96": 95.9341334, 
    "Rb-97": 96.9371771, 
    "Rb-98": 97.9416869, 
    "Rb-99": 98.94503, 
    "Rb-100": 99.95003, 
    "Rb-101": 100.95404, 
    "Rb-102": 101.95952, 
    "Rb-103": 102.96392, 
    "Sr-73": 72.9657, 
    "Sr-74": 73.95617, 
    "Sr-75": 74.94995, 
    "Sr-76": 75.941763, 
    "Sr-77": 76.9379455, 
    "Sr-78": 77.93218, 
    "Sr-79": 78.9297077, 
    "Sr-80": 79.9245175, 
    "Sr-81": 80.9232114, 
    "Sr-82": 81.9183999, 
    "Sr-83": 82.9175544, 
    "Sr-84": 83.9134191, 
    "Sr-85": 84.912932, 
    "Sr-86": 85.9092606, 
    "Sr-87": 86.9088775, 
    "Sr-88": 87.9056125, 
    "Sr-89": 88.9074511, 
    "Sr-90": 89.90773, 
    "Sr-91": 90.9101954, 
    "Sr-92": 91.9110382, 
    "Sr-93": 92.9140242, 
    "Sr-94": 93.9153556, 
    "Sr-95": 94.9193529, 
    "Sr-96": 95.9217066, 
    "Sr-97": 96.926374, 
    "Sr-98": 97.9286888, 
    "Sr-99": 98.9328907, 
    "Sr-100": 99.93577, 
    "Sr-101": 100.940352, 
    "Sr-102": 101.943791, 
    "Sr-103": 102.94909, 
    "Sr-104": 103.95265, 
    "Sr-105": 104.95855, 
    "Sr-106": 105.96265, 
    "Sr-107": 106.96897, 
    "Y-76": 75.95856, 
    "Y-77": 76.949781, 
    "Y-78": 77.94361, 
    "Y-79": 78.93735, 
    "Y-80": 79.9343561, 
    "Y-81": 80.9294556, 
    "Y-82": 81.9269314, 
    "Y-83": 82.922485, 
    "Y-84": 83.9206721, 
    "Y-85": 84.916433, 
    "Y-86": 85.914886, 
    "Y-87": 86.9108761, 
    "Y-88": 87.9095016, 
    "Y-89": 88.9058403, 
    "Y-90": 89.9071439, 
    "Y-91": 90.9072974, 
    "Y-92": 91.9089451, 
    "Y-93": 92.909578, 
    "Y-94": 93.9115906, 
    "Y-95": 94.9128161, 
    "Y-96": 95.9158968, 
    "Y-97": 96.9182741, 
    "Y-98": 97.9223821, 
    "Y-99": 98.924148, 
    "Y-100": 99.927715, 
    "Y-101": 100.9301477, 
    "Y-102": 101.9343277, 
    "Y-103": 102.937243, 
    "Y-104": 103.94196, 
    "Y-105": 104.94544, 
    "Y-106": 105.95056, 
    "Y-107": 106.95452, 
    "Y-108": 107.95996, 
    "Y-109": 108.96436, 
    "Zr-78": 77.95566, 
    "Zr-79": 78.94948, 
    "Zr-80": 79.9404, 
    "Zr-81": 80.93731, 
    "Zr-82": 81.93135, 
    "Zr-83": 82.9292421, 
    "Zr-84": 83.9233269, 
    "Zr-85": 84.9214444, 
    "Zr-86": 85.9162972, 
    "Zr-87": 86.914818, 
    "Zr-88": 87.9102213, 
    "Zr-89": 88.9088814, 
    "Zr-90": 89.9046977, 
    "Zr-91": 90.9056396, 
    "Zr-92": 91.9050347, 
    "Zr-93": 92.9064699, 
    "Zr-94": 93.9063108, 
    "Zr-95": 94.9080385, 
    "Zr-96": 95.9082714, 
    "Zr-97": 96.9109512, 
    "Zr-98": 97.9127289, 
    "Zr-99": 98.916667, 
    "Zr-100": 99.9180006, 
    "Zr-101": 100.921448, 
    "Zr-102": 101.9231409, 
    "Zr-103": 102.927191, 
    "Zr-104": 103.929436, 
    "Zr-105": 104.934008, 
    "Zr-106": 105.93676, 
    "Zr-107": 106.94174, 
    "Zr-108": 107.94487, 
    "Zr-109": 108.95041, 
    "Zr-110": 109.95396, 
    "Zr-111": 110.95968, 
    "Zr-112": 111.9637, 
    "Nb-81": 80.9496, 
    "Nb-82": 81.94396, 
    "Nb-83": 82.93729, 
    "Nb-84": 83.93449, 
    "Nb-85": 84.9288458, 
    "Nb-86": 85.9257828, 
    "Nb-87": 86.9206937, 
    "Nb-88": 87.918222, 
    "Nb-89": 88.913445, 
    "Nb-90": 89.9112584, 
    "Nb-91": 90.9069897, 
    "Nb-92": 91.9071881, 
    "Nb-93": 92.906373, 
    "Nb-94": 93.9072788, 
    "Nb-95": 94.9068324, 
    "Nb-96": 95.9080973, 
    "Nb-97": 96.9080959, 
    "Nb-98": 97.9103265, 
    "Nb-99": 98.911613, 
    "Nb-100": 99.9143276, 
    "Nb-101": 100.9153103, 
    "Nb-102": 101.9180772, 
    "Nb-103": 102.9194572, 
    "Nb-104": 103.9228925, 
    "Nb-105": 104.9249465, 
    "Nb-106": 105.9289317, 
    "Nb-107": 106.9315937, 
    "Nb-108": 107.9360748, 
    "Nb-109": 108.93922, 
    "Nb-110": 109.94403, 
    "Nb-111": 110.94753, 
    "Nb-112": 111.95247, 
    "Nb-113": 112.95651, 
    "Nb-114": 113.96201, 
    "Nb-115": 114.96634, 
    "Mo-83": 82.94988, 
    "Mo-84": 83.94149, 
    "Mo-85": 84.938261, 
    "Mo-86": 85.9311748, 
    "Mo-87": 86.9281962, 
    "Mo-88": 87.9219678, 
    "Mo-89": 88.9194682, 
    "Mo-90": 89.9139309, 
    "Mo-91": 90.9117453, 
    "Mo-92": 91.90680796, 
    "Mo-93": 92.90680958, 
    "Mo-94": 93.9050849, 
    "Mo-95": 94.90583877, 
    "Mo-96": 95.90467612, 
    "Mo-97": 96.90601812, 
    "Mo-98": 97.90540482, 
    "Mo-99": 98.90770851, 
    "Mo-100": 99.9074718, 
    "Mo-101": 100.9103414, 
    "Mo-102": 101.9102834, 
    "Mo-103": 102.913079, 
    "Mo-104": 103.9137344, 
    "Mo-105": 104.916969, 
    "Mo-106": 105.918259, 
    "Mo-107": 106.922106, 
    "Mo-108": 107.924033, 
    "Mo-109": 108.928424, 
    "Mo-110": 109.930704, 
    "Mo-111": 110.935654, 
    "Mo-112": 111.93831, 
    "Mo-113": 112.94335, 
    "Mo-114": 113.94653, 
    "Mo-115": 114.95196, 
    "Mo-116": 115.95545, 
    "Mo-117": 116.96117, 
    "Tc-85": 84.95058, 
    "Tc-86": 85.94493, 
    "Tc-87": 86.9380672, 
    "Tc-88": 87.93378, 
    "Tc-89": 88.9276487, 
    "Tc-90": 89.9240739, 
    "Tc-91": 90.9184254, 
    "Tc-92": 91.9152698, 
    "Tc-93": 92.910246, 
    "Tc-94": 93.9096536, 
    "Tc-95": 94.9076536, 
    "Tc-96": 95.907868, 
    "Tc-97": 96.9063667, 
    "Tc-98": 97.9072124, 
    "Tc-99": 98.9062508, 
    "Tc-100": 99.9076539, 
    "Tc-101": 100.907309, 
    "Tc-102": 101.9092097, 
    "Tc-103": 102.909176, 
    "Tc-104": 103.911425, 
    "Tc-105": 104.911655, 
    "Tc-106": 105.914358, 
    "Tc-107": 106.9154606, 
    "Tc-108": 107.9184957, 
    "Tc-109": 108.920256, 
    "Tc-110": 109.923744, 
    "Tc-111": 110.925901, 
    "Tc-112": 111.9299458, 
    "Tc-113": 112.932569, 
    "Tc-114": 113.93691, 
    "Tc-115": 114.93998, 
    "Tc-116": 115.94476, 
    "Tc-117": 116.94806, 
    "Tc-118": 117.95299, 
    "Tc-119": 118.95666, 
    "Tc-120": 119.96187, 
    "Ru-87": 86.95069, 
    "Ru-88": 87.9416, 
    "Ru-89": 88.93762, 
    "Ru-90": 89.9303444, 
    "Ru-91": 90.9267419, 
    "Ru-92": 91.9202344, 
    "Ru-93": 92.9171044, 
    "Ru-94": 93.9113429, 
    "Ru-95": 94.910406, 
    "Ru-96": 95.90759025, 
    "Ru-97": 96.9075471, 
    "Ru-98": 97.9052868, 
    "Ru-99": 98.9059341, 
    "Ru-100": 99.9042143, 
    "Ru-101": 100.9055769, 
    "Ru-102": 101.9043441, 
    "Ru-103": 102.9063186, 
    "Ru-104": 103.9054275, 
    "Ru-105": 104.9077476, 
    "Ru-106": 105.9073291, 
    "Ru-107": 106.909972, 
    "Ru-108": 107.910188, 
    "Ru-109": 108.913326, 
    "Ru-110": 109.9140407, 
    "Ru-111": 110.91757, 
    "Ru-112": 111.918809, 
    "Ru-113": 112.922844, 
    "Ru-114": 113.9246136, 
    "Ru-115": 114.92882, 
    "Ru-116": 115.9312192, 
    "Ru-117": 116.9361, 
    "Ru-118": 117.93853, 
    "Ru-119": 118.94357, 
    "Ru-120": 119.94631, 
    "Ru-121": 120.95164, 
    "Ru-122": 121.95447, 
    "Ru-123": 122.95989, 
    "Ru-124": 123.96305, 
    "Rh-89": 88.95058, 
    "Rh-90": 89.94422, 
    "Rh-91": 90.93688, 
    "Rh-92": 91.9323677, 
    "Rh-93": 92.9259128, 
    "Rh-94": 93.9217305, 
    "Rh-95": 94.9158979, 
    "Rh-96": 95.914453, 
    "Rh-97": 96.911329, 
    "Rh-98": 97.910708, 
    "Rh-99": 98.9081282, 
    "Rh-100": 99.908117, 
    "Rh-101": 100.9061606, 
    "Rh-102": 101.9068374, 
    "Rh-103": 102.905498, 
    "Rh-104": 103.9066492, 
    "Rh-105": 104.9056885, 
    "Rh-106": 105.9072868, 
    "Rh-107": 106.906748, 
    "Rh-108": 107.908714, 
    "Rh-109": 108.9087488, 
    "Rh-110": 109.911079, 
    "Rh-111": 110.9116423, 
    "Rh-112": 111.914403, 
    "Rh-113": 112.9154393, 
    "Rh-114": 113.918718, 
    "Rh-115": 114.9203116, 
    "Rh-116": 115.924059, 
    "Rh-117": 116.9260354, 
    "Rh-118": 117.93034, 
    "Rh-119": 118.932557, 
    "Rh-120": 119.93686, 
    "Rh-121": 120.93942, 
    "Rh-122": 121.94399, 
    "Rh-123": 122.94685, 
    "Rh-124": 123.95151, 
    "Rh-125": 124.95469, 
    "Rh-126": 125.95946, 
    "Pd-91": 90.95032, 
    "Pd-92": 91.94088, 
    "Pd-93": 92.93651, 
    "Pd-94": 93.9290376, 
    "Pd-95": 94.9248898, 
    "Pd-96": 95.9182151, 
    "Pd-97": 96.916472, 
    "Pd-98": 97.9126983, 
    "Pd-99": 98.9117748, 
    "Pd-100": 99.908505, 
    "Pd-101": 100.9082864, 
    "Pd-102": 101.9056022, 
    "Pd-103": 102.9060809, 
    "Pd-104": 103.9040305, 
    "Pd-105": 104.9050796, 
    "Pd-106": 105.9034804, 
    "Pd-107": 106.9051282, 
    "Pd-108": 107.9038916, 
    "Pd-109": 108.9059504, 
    "Pd-110": 109.9051722, 
    "Pd-111": 110.90768968, 
    "Pd-112": 111.9073297, 
    "Pd-113": 112.910261, 
    "Pd-114": 113.9103686, 
    "Pd-115": 114.913659, 
    "Pd-116": 115.914297, 
    "Pd-117": 116.9179547, 
    "Pd-118": 117.9190667, 
    "Pd-119": 118.9233402, 
    "Pd-120": 119.9245511, 
    "Pd-121": 120.9289503, 
    "Pd-122": 121.930632, 
    "Pd-123": 122.93514, 
    "Pd-124": 123.93714, 
    "Pd-125": 124.94179, 
    "Pd-126": 125.94416, 
    "Pd-127": 126.94907, 
    "Pd-128": 127.95183, 
    "Ag-93": 92.95033, 
    "Ag-94": 93.94373, 
    "Ag-95": 94.93602, 
    "Ag-96": 95.930744, 
    "Ag-97": 96.92397, 
    "Ag-98": 97.92156, 
    "Ag-99": 98.9176458, 
    "Ag-100": 99.9161154, 
    "Ag-101": 100.912684, 
    "Ag-102": 101.9117047, 
    "Ag-103": 102.9089631, 
    "Ag-104": 103.9086239, 
    "Ag-105": 104.9065256, 
    "Ag-106": 105.9066636, 
    "Ag-107": 106.9050916, 
    "Ag-108": 107.9059503, 
    "Ag-109": 108.9047553, 
    "Ag-110": 109.9061102, 
    "Ag-111": 110.9052959, 
    "Ag-112": 111.9070486, 
    "Ag-113": 112.906573, 
    "Ag-114": 113.908823, 
    "Ag-115": 114.908767, 
    "Ag-116": 115.9113868, 
    "Ag-117": 116.911774, 
    "Ag-118": 117.9145955, 
    "Ag-119": 118.91557, 
    "Ag-120": 119.9187848, 
    "Ag-121": 120.920125, 
    "Ag-122": 121.923664, 
    "Ag-123": 122.925337, 
    "Ag-124": 123.92893, 
    "Ag-125": 124.93105, 
    "Ag-126": 125.93475, 
    "Ag-127": 126.93711, 
    "Ag-128": 127.94106, 
    "Ag-129": 128.94395, 
    "Ag-130": 129.9507, 
    "Cd-95": 94.94994, 
    "Cd-96": 95.94034, 
    "Cd-97": 96.9351, 
    "Cd-98": 97.927389, 
    "Cd-99": 98.9249258, 
    "Cd-100": 99.9203488, 
    "Cd-101": 100.9185862, 
    "Cd-102": 101.914482, 
    "Cd-103": 102.9134165, 
    "Cd-104": 103.9098564, 
    "Cd-105": 104.9094639, 
    "Cd-106": 105.9064599, 
    "Cd-107": 106.9066121, 
    "Cd-108": 107.9041834, 
    "Cd-109": 108.9049867, 
    "Cd-110": 109.90300661, 
    "Cd-111": 110.90418287, 
    "Cd-112": 111.90276287, 
    "Cd-113": 112.90440813, 
    "Cd-114": 113.90336509, 
    "Cd-115": 114.90543751, 
    "Cd-116": 115.90476315, 
    "Cd-117": 116.907226, 
    "Cd-118": 117.906922, 
    "Cd-119": 118.909847, 
    "Cd-120": 119.9098681, 
    "Cd-121": 120.9129637, 
    "Cd-122": 121.9134591, 
    "Cd-123": 122.9168925, 
    "Cd-124": 123.9176574, 
    "Cd-125": 124.9212576, 
    "Cd-126": 125.9224291, 
    "Cd-127": 126.926472, 
    "Cd-128": 127.9278129, 
    "Cd-129": 128.93182, 
    "Cd-130": 129.93394, 
    "Cd-131": 130.9406, 
    "Cd-132": 131.94604, 
    "Cd-133": 132.95285, 
    "In-97": 96.94934, 
    "In-98": 97.94214, 
    "In-99": 98.93411, 
    "In-100": 99.93096, 
    "In-101": 100.92634, 
    "In-102": 101.9241071, 
    "In-103": 102.9198819, 
    "In-104": 103.9182145, 
    "In-105": 104.914502, 
    "In-106": 105.913464, 
    "In-107": 106.91029, 
    "In-108": 107.9096935, 
    "In-109": 108.9071514, 
    "In-110": 109.90717, 
    "In-111": 110.9051085, 
    "In-112": 111.9055377, 
    "In-113": 112.90406184, 
    "In-114": 113.90491791, 
    "In-115": 114.903878776, 
    "In-116": 115.90525999, 
    "In-117": 116.9045157, 
    "In-118": 117.9063566, 
    "In-119": 118.9058507, 
    "In-120": 119.907967, 
    "In-121": 120.907851, 
    "In-122": 121.910281, 
    "In-123": 122.910434, 
    "In-124": 123.913182, 
    "In-125": 124.913605, 
    "In-126": 125.916507, 
    "In-127": 126.917446, 
    "In-128": 127.9204, 
    "In-129": 128.9218053, 
    "In-130": 129.924977, 
    "In-131": 130.9269715, 
    "In-132": 131.933001, 
    "In-133": 132.93831, 
    "In-134": 133.94454, 
    "In-135": 134.95005, 
    "Sn-99": 98.94853, 
    "Sn-100": 99.9385, 
    "Sn-101": 100.93526, 
    "Sn-102": 101.93029, 
    "Sn-103": 102.928105, 
    "Sn-104": 103.9231052, 
    "Sn-105": 104.9212684, 
    "Sn-106": 105.9169574, 
    "Sn-107": 106.9157137, 
    "Sn-108": 107.9118943, 
    "Sn-109": 108.9112921, 
    "Sn-110": 109.907845, 
    "Sn-111": 110.9077401, 
    "Sn-112": 111.90482387, 
    "Sn-113": 112.9051757, 
    "Sn-114": 113.9027827, 
    "Sn-115": 114.903344699, 
    "Sn-116": 115.9017428, 
    "Sn-117": 116.90295398, 
    "Sn-118": 117.90160657, 
    "Sn-119": 118.90331117, 
    "Sn-120": 119.90220163, 
    "Sn-121": 120.9042426, 
    "Sn-122": 121.9034438, 
    "Sn-123": 122.9057252, 
    "Sn-124": 123.9052766, 
    "Sn-125": 124.9077864, 
    "Sn-126": 125.907659, 
    "Sn-127": 126.91039, 
    "Sn-128": 127.910507, 
    "Sn-129": 128.913465, 
    "Sn-130": 129.9139738, 
    "Sn-131": 130.917045, 
    "Sn-132": 131.9178267, 
    "Sn-133": 132.9239134, 
    "Sn-134": 133.9286821, 
    "Sn-135": 134.9349086, 
    "Sn-136": 135.93999, 
    "Sn-137": 136.94655, 
    "Sn-138": 137.95184, 
    "Sb-103": 102.93969, 
    "Sb-104": 103.93648, 
    "Sb-105": 104.931276, 
    "Sb-106": 105.928638, 
    "Sb-107": 106.9241506, 
    "Sb-108": 107.9222267, 
    "Sb-109": 108.9181411, 
    "Sb-110": 109.9168543, 
    "Sb-111": 110.9132182, 
    "Sb-112": 111.9124, 
    "Sb-113": 112.909375, 
    "Sb-114": 113.90929, 
    "Sb-115": 114.906598, 
    "Sb-116": 115.9067931, 
    "Sb-117": 116.9048415, 
    "Sb-118": 117.9055321, 
    "Sb-119": 118.9039455, 
    "Sb-120": 119.9050794, 
    "Sb-121": 120.903812, 
    "Sb-122": 121.9051699, 
    "Sb-123": 122.9042132, 
    "Sb-124": 123.905935, 
    "Sb-125": 124.905253, 
    "Sb-126": 125.907253, 
    "Sb-127": 126.9069243, 
    "Sb-128": 127.909146, 
    "Sb-129": 128.909147, 
    "Sb-130": 129.911662, 
    "Sb-131": 130.9119888, 
    "Sb-132": 131.9145077, 
    "Sb-133": 132.9152732, 
    "Sb-134": 133.9205357, 
    "Sb-135": 134.9251851, 
    "Sb-136": 135.9307459, 
    "Sb-137": 136.93555, 
    "Sb-138": 137.94145, 
    "Sb-139": 138.94655, 
    "Sb-140": 139.95283, 
    "Te-105": 104.9433, 
    "Te-106": 105.9375, 
    "Te-107": 106.935012, 
    "Te-108": 107.9293805, 
    "Te-109": 108.9273045, 
    "Te-110": 109.9224581, 
    "Te-111": 110.9210006, 
    "Te-112": 111.9167279, 
    "Te-113": 112.915891, 
    "Te-114": 113.912089, 
    "Te-115": 114.911902, 
    "Te-116": 115.90846, 
    "Te-117": 116.908646, 
    "Te-118": 117.905854, 
    "Te-119": 118.9064071, 
    "Te-120": 119.9040593, 
    "Te-121": 120.904944, 
    "Te-122": 121.9030435, 
    "Te-123": 122.9042698, 
    "Te-124": 123.9028171, 
    "Te-125": 124.9044299, 
    "Te-126": 125.9033109, 
    "Te-127": 126.9052257, 
    "Te-128": 127.90446128, 
    "Te-129": 128.90659646, 
    "Te-130": 129.906222748, 
    "Te-131": 130.908522213, 
    "Te-132": 131.9085467, 
    "Te-133": 132.9109688, 
    "Te-134": 133.911394, 
    "Te-135": 134.9165557, 
    "Te-136": 135.9201006, 
    "Te-137": 136.9255989, 
    "Te-138": 137.9294722, 
    "Te-139": 138.9353672, 
    "Te-140": 139.939499, 
    "Te-141": 140.9458, 
    "Te-142": 141.95022, 
    "Te-143": 142.95676, 
    "I-107": 106.94678, 
    "I-108": 107.94348, 
    "I-109": 108.9380853, 
    "I-110": 109.935089, 
    "I-111": 110.9302692, 
    "I-112": 111.928005, 
    "I-113": 112.9236501, 
    "I-114": 113.92185, 
    "I-115": 114.918048, 
    "I-116": 115.91681, 
    "I-117": 116.913648, 
    "I-118": 117.913074, 
    "I-119": 118.910074, 
    "I-120": 119.910087, 
    "I-121": 120.9074051, 
    "I-122": 121.9075888, 
    "I-123": 122.9055885, 
    "I-124": 123.906209, 
    "I-125": 124.9046294, 
    "I-126": 125.9056233, 
    "I-127": 126.9044719, 
    "I-128": 127.9058086, 
    "I-129": 128.9049837, 
    "I-130": 129.9066702, 
    "I-131": 130.9061263, 
    "I-132": 131.9079935, 
    "I-133": 132.907797, 
    "I-134": 133.9097588, 
    "I-135": 134.9100488, 
    "I-136": 135.914604, 
    "I-137": 136.9180282, 
    "I-138": 137.9227264, 
    "I-139": 138.926506, 
    "I-140": 139.93173, 
    "I-141": 140.93569, 
    "I-142": 141.9412, 
    "I-143": 142.94565, 
    "I-144": 143.95139, 
    "I-145": 144.95605, 
    "Xe-109": 108.95043, 
    "Xe-110": 109.94426, 
    "Xe-111": 110.941607, 
    "Xe-112": 111.935559, 
    "Xe-113": 112.9332217, 
    "Xe-114": 113.92798, 
    "Xe-115": 114.926294, 
    "Xe-116": 115.921581, 
    "Xe-117": 116.920359, 
    "Xe-118": 117.916179, 
    "Xe-119": 118.915411, 
    "Xe-120": 119.911784, 
    "Xe-121": 120.911453, 
    "Xe-122": 121.908368, 
    "Xe-123": 122.908482, 
    "Xe-124": 123.905892, 
    "Xe-125": 124.9063944, 
    "Xe-126": 125.9042983, 
    "Xe-127": 126.9051829, 
    "Xe-128": 127.903531, 
    "Xe-129": 128.9047808611, 
    "Xe-130": 129.903509349, 
    "Xe-131": 130.90508406, 
    "Xe-132": 131.9041550856, 
    "Xe-133": 132.9059108, 
    "Xe-134": 133.90539466, 
    "Xe-135": 134.9072278, 
    "Xe-136": 135.907214484, 
    "Xe-137": 136.91155778, 
    "Xe-138": 137.9141463, 
    "Xe-139": 138.9187922, 
    "Xe-140": 139.9216458, 
    "Xe-141": 140.9267872, 
    "Xe-142": 141.9299731, 
    "Xe-143": 142.9353696, 
    "Xe-144": 143.9389451, 
    "Xe-145": 144.94472, 
    "Xe-146": 145.948518, 
    "Xe-147": 146.95426, 
    "Xe-148": 147.95813, 
    "Cs-112": 111.950309, 
    "Cs-113": 112.9444291, 
    "Cs-114": 113.941296, 
    "Cs-115": 114.93591, 
    "Cs-116": 115.93337, 
    "Cs-117": 116.928617, 
    "Cs-118": 117.92656, 
    "Cs-119": 118.922377, 
    "Cs-120": 119.920677, 
    "Cs-121": 120.917227, 
    "Cs-122": 121.916108, 
    "Cs-123": 122.912996, 
    "Cs-124": 123.9122578, 
    "Cs-125": 124.909728, 
    "Cs-126": 125.909446, 
    "Cs-127": 126.9074174, 
    "Cs-128": 127.9077487, 
    "Cs-129": 128.9060657, 
    "Cs-130": 129.9067093, 
    "Cs-131": 130.9054649, 
    "Cs-132": 131.9064339, 
    "Cs-133": 132.905451961, 
    "Cs-134": 133.906718503, 
    "Cs-135": 134.905977, 
    "Cs-136": 135.9073114, 
    "Cs-137": 136.90708923, 
    "Cs-138": 137.9110171, 
    "Cs-139": 138.9133638, 
    "Cs-140": 139.9172831, 
    "Cs-141": 140.9200455, 
    "Cs-142": 141.924296, 
    "Cs-143": 142.927349, 
    "Cs-144": 143.932076, 
    "Cs-145": 144.935527, 
    "Cs-146": 145.940344, 
    "Cs-147": 146.944156, 
    "Cs-148": 147.94923, 
    "Cs-149": 148.95302, 
    "Cs-150": 149.95833, 
    "Cs-151": 150.96258, 
    "Ba-114": 113.95066, 
    "Ba-115": 114.94737, 
    "Ba-116": 115.94128, 
    "Ba-117": 116.93814, 
    "Ba-118": 117.93306, 
    "Ba-119": 118.93066, 
    "Ba-120": 119.92605, 
    "Ba-121": 120.92405, 
    "Ba-122": 121.919904, 
    "Ba-123": 122.918781, 
    "Ba-124": 123.915094, 
    "Ba-125": 124.914472, 
    "Ba-126": 125.91125, 
    "Ba-127": 126.911091, 
    "Ba-128": 127.908342, 
    "Ba-129": 128.908681, 
    "Ba-130": 129.9063207, 
    "Ba-131": 130.906941, 
    "Ba-132": 131.9050611, 
    "Ba-133": 132.9060074, 
    "Ba-134": 133.90450818, 
    "Ba-135": 134.90568838, 
    "Ba-136": 135.90457573, 
    "Ba-137": 136.90582714, 
    "Ba-138": 137.905247, 
    "Ba-139": 138.9088411, 
    "Ba-140": 139.9106057, 
    "Ba-141": 140.9144033, 
    "Ba-142": 141.9164324, 
    "Ba-143": 142.9206253, 
    "Ba-144": 143.9229549, 
    "Ba-145": 144.9275184, 
    "Ba-146": 145.930284, 
    "Ba-147": 146.935304, 
    "Ba-148": 147.938171, 
    "Ba-149": 148.94308, 
    "Ba-150": 149.94605, 
    "Ba-151": 150.95127, 
    "Ba-152": 151.95481, 
    "Ba-153": 152.96036, 
    "La-116": 115.9563, 
    "La-117": 116.94999, 
    "La-118": 117.94673, 
    "La-119": 118.94099, 
    "La-120": 119.93807, 
    "La-121": 120.93315, 
    "La-122": 121.93071, 
    "La-123": 122.9263, 
    "La-124": 123.924574, 
    "La-125": 124.920816, 
    "La-126": 125.919513, 
    "La-127": 126.916375, 
    "La-128": 127.915592, 
    "La-129": 128.912694, 
    "La-130": 129.912369, 
    "La-131": 130.91007, 
    "La-132": 131.910119, 
    "La-133": 132.908218, 
    "La-134": 133.908514, 
    "La-135": 134.906984, 
    "La-136": 135.907635, 
    "La-137": 136.9064504, 
    "La-138": 137.9071149, 
    "La-139": 138.9063563, 
    "La-140": 139.9094806, 
    "La-141": 140.910966, 
    "La-142": 141.9140909, 
    "La-143": 142.9160795, 
    "La-144": 143.919646, 
    "La-145": 144.921808, 
    "La-146": 145.925875, 
    "La-147": 146.928418, 
    "La-148": 147.932679, 
    "La-149": 148.93535, 
    "La-150": 149.93947, 
    "La-151": 150.94232, 
    "La-152": 151.94682, 
    "La-153": 152.95036, 
    "La-154": 153.95517, 
    "La-155": 154.95901, 
    "Ce-119": 118.95271, 
    "Ce-120": 119.94654, 
    "Ce-121": 120.94335, 
    "Ce-122": 121.93787, 
    "Ce-123": 122.93528, 
    "Ce-124": 123.93031, 
    "Ce-125": 124.92844, 
    "Ce-126": 125.923971, 
    "Ce-127": 126.922727, 
    "Ce-128": 127.918911, 
    "Ce-129": 128.918102, 
    "Ce-130": 129.914736, 
    "Ce-131": 130.914429, 
    "Ce-132": 131.911464, 
    "Ce-133": 132.91152, 
    "Ce-134": 133.908928, 
    "Ce-135": 134.909161, 
    "Ce-136": 135.90712921, 
    "Ce-137": 136.90776236, 
    "Ce-138": 137.905991, 
    "Ce-139": 138.9066551, 
    "Ce-140": 139.9054431, 
    "Ce-141": 140.9082807, 
    "Ce-142": 141.9092504, 
    "Ce-143": 142.9123921, 
    "Ce-144": 143.9136529, 
    "Ce-145": 144.917265, 
    "Ce-146": 145.918802, 
    "Ce-147": 146.9226899, 
    "Ce-148": 147.924424, 
    "Ce-149": 148.928427, 
    "Ce-150": 149.930384, 
    "Ce-151": 150.934272, 
    "Ce-152": 151.9366, 
    "Ce-153": 152.94093, 
    "Ce-154": 153.9438, 
    "Ce-155": 154.94855, 
    "Ce-156": 155.95183, 
    "Ce-157": 156.95705, 
    "Pr-121": 120.95532, 
    "Pr-122": 121.95175, 
    "Pr-123": 122.94596, 
    "Pr-124": 123.94294, 
    "Pr-125": 124.9377, 
    "Pr-126": 125.93524, 
    "Pr-127": 126.93071, 
    "Pr-128": 127.928791, 
    "Pr-129": 128.925095, 
    "Pr-130": 129.92359, 
    "Pr-131": 130.920235, 
    "Pr-132": 131.919255, 
    "Pr-133": 132.916331, 
    "Pr-134": 133.915697, 
    "Pr-135": 134.913112, 
    "Pr-136": 135.912677, 
    "Pr-137": 136.9106792, 
    "Pr-138": 137.910754, 
    "Pr-139": 138.9089408, 
    "Pr-140": 139.9090803, 
    "Pr-141": 140.9076576, 
    "Pr-142": 141.9100496, 
    "Pr-143": 142.9108228, 
    "Pr-144": 143.9133109, 
    "Pr-145": 144.9145182, 
    "Pr-146": 145.91768, 
    "Pr-147": 146.919008, 
    "Pr-148": 147.92213, 
    "Pr-149": 148.923736, 
    "Pr-150": 149.9266765, 
    "Pr-151": 150.928309, 
    "Pr-152": 151.931553, 
    "Pr-153": 152.933904, 
    "Pr-154": 153.93753, 
    "Pr-155": 154.940509, 
    "Pr-156": 155.94464, 
    "Pr-157": 156.94789, 
    "Pr-158": 157.95241, 
    "Pr-159": 158.95589, 
    "Nd-124": 123.9522, 
    "Nd-125": 124.9489, 
    "Nd-126": 125.94311, 
    "Nd-127": 126.94038, 
    "Nd-128": 127.93525, 
    "Nd-129": 128.9331, 
    "Nd-130": 129.928506, 
    "Nd-131": 130.927248, 
    "Nd-132": 131.923321, 
    "Nd-133": 132.922348, 
    "Nd-134": 133.91879, 
    "Nd-135": 134.918181, 
    "Nd-136": 135.914976, 
    "Nd-137": 136.914562, 
    "Nd-138": 137.91195, 
    "Nd-139": 138.911954, 
    "Nd-140": 139.90955, 
    "Nd-141": 140.9096147, 
    "Nd-142": 141.907729, 
    "Nd-143": 142.90982, 
    "Nd-144": 143.910093, 
    "Nd-145": 144.9125793, 
    "Nd-146": 145.9131226, 
    "Nd-147": 146.9161061, 
    "Nd-148": 147.9168993, 
    "Nd-149": 148.9201548, 
    "Nd-150": 149.9209022, 
    "Nd-151": 150.9238403, 
    "Nd-152": 151.924692, 
    "Nd-153": 152.927718, 
    "Nd-154": 153.92948, 
    "Nd-155": 154.9331357, 
    "Nd-156": 155.93508, 
    "Nd-157": 156.939386, 
    "Nd-158": 157.94197, 
    "Nd-159": 158.94653, 
    "Nd-160": 159.9494, 
    "Nd-161": 160.95428, 
    "Pm-126": 125.95792, 
    "Pm-127": 126.95192, 
    "Pm-128": 127.9487, 
    "Pm-129": 128.94323, 
    "Pm-130": 129.94053, 
    "Pm-131": 130.93567, 
    "Pm-132": 131.93384, 
    "Pm-133": 132.929782, 
    "Pm-134": 133.928353, 
    "Pm-135": 134.924823, 
    "Pm-136": 135.923585, 
    "Pm-137": 136.92048, 
    "Pm-138": 137.919548, 
    "Pm-139": 138.9168, 
    "Pm-140": 139.91604, 
    "Pm-141": 140.913555, 
    "Pm-142": 141.91289, 
    "Pm-143": 142.9109383, 
    "Pm-144": 143.9125964, 
    "Pm-145": 144.9127559, 
    "Pm-146": 145.9147024, 
    "Pm-147": 146.915145, 
    "Pm-148": 147.9174819, 
    "Pm-149": 148.9183423, 
    "Pm-150": 149.920991, 
    "Pm-151": 150.9212175, 
    "Pm-152": 151.923506, 
    "Pm-153": 152.9241567, 
    "Pm-154": 153.926472, 
    "Pm-155": 154.928137, 
    "Pm-156": 155.9311175, 
    "Pm-157": 156.9331214, 
    "Pm-158": 157.936565, 
    "Pm-159": 158.939287, 
    "Pm-160": 159.9431, 
    "Pm-161": 160.94607, 
    "Pm-162": 161.95022, 
    "Pm-163": 162.95357, 
    "Sm-128": 127.95842, 
    "Sm-129": 128.95476, 
    "Sm-130": 129.949, 
    "Sm-131": 130.94618, 
    "Sm-132": 131.94087, 
    "Sm-133": 132.93856, 
    "Sm-134": 133.93411, 
    "Sm-135": 134.93252, 
    "Sm-136": 135.928276, 
    "Sm-137": 136.926971, 
    "Sm-138": 137.923244, 
    "Sm-139": 138.922297, 
    "Sm-140": 139.918995, 
    "Sm-141": 140.9184816, 
    "Sm-142": 141.9152044, 
    "Sm-143": 142.9146353, 
    "Sm-144": 143.9120065, 
    "Sm-145": 144.9134173, 
    "Sm-146": 145.913047, 
    "Sm-147": 146.9149044, 
    "Sm-148": 147.9148292, 
    "Sm-149": 148.9171921, 
    "Sm-150": 149.9172829, 
    "Sm-151": 150.9199398, 
    "Sm-152": 151.9197397, 
    "Sm-153": 152.9221047, 
    "Sm-154": 153.9222169, 
    "Sm-155": 154.9246477, 
    "Sm-156": 155.925536, 
    "Sm-157": 156.9284187, 
    "Sm-158": 157.929951, 
    "Sm-159": 158.9332172, 
    "Sm-160": 159.9353353, 
    "Sm-161": 160.9391602, 
    "Sm-162": 161.94146, 
    "Sm-163": 162.94555, 
    "Sm-164": 163.94836, 
    "Sm-165": 164.95297, 
    "Eu-130": 129.96369, 
    "Eu-131": 130.95784, 
    "Eu-132": 131.95467, 
    "Eu-133": 132.94929, 
    "Eu-134": 133.9464, 
    "Eu-135": 134.94187, 
    "Eu-136": 135.93962, 
    "Eu-137": 136.93546, 
    "Eu-138": 137.933709, 
    "Eu-139": 138.929792, 
    "Eu-140": 139.928088, 
    "Eu-141": 140.924932, 
    "Eu-142": 141.923442, 
    "Eu-143": 142.920299, 
    "Eu-144": 143.91882, 
    "Eu-145": 144.9162726, 
    "Eu-146": 145.917211, 
    "Eu-147": 146.9167527, 
    "Eu-148": 147.918089, 
    "Eu-149": 148.9179378, 
    "Eu-150": 149.9197077, 
    "Eu-151": 150.9198578, 
    "Eu-152": 151.9217522, 
    "Eu-153": 152.921238, 
    "Eu-154": 153.922987, 
    "Eu-155": 154.9229011, 
    "Eu-156": 155.9247605, 
    "Eu-157": 156.9254334, 
    "Eu-158": 157.927799, 
    "Eu-159": 158.9291001, 
    "Eu-160": 159.931851, 
    "Eu-161": 160.933664, 
    "Eu-162": 161.936989, 
    "Eu-163": 162.939196, 
    "Eu-164": 163.94274, 
    "Eu-165": 164.94559, 
    "Eu-166": 165.94962, 
    "Eu-167": 166.95289, 
    "Gd-133": 132.96133, 
    "Gd-134": 133.95566, 
    "Gd-135": 134.95245, 
    "Gd-136": 135.9473, 
    "Gd-137": 136.94502, 
    "Gd-138": 137.94025, 
    "Gd-139": 138.93813, 
    "Gd-140": 139.933674, 
    "Gd-141": 140.932126, 
    "Gd-142": 141.928116, 
    "Gd-143": 142.92675, 
    "Gd-144": 143.922963, 
    "Gd-145": 144.921713, 
    "Gd-146": 145.9183188, 
    "Gd-147": 146.9191014, 
    "Gd-148": 147.9181215, 
    "Gd-149": 148.9193481, 
    "Gd-150": 149.9186644, 
    "Gd-151": 150.920356, 
    "Gd-152": 151.9197995, 
    "Gd-153": 152.921758, 
    "Gd-154": 153.9208741, 
    "Gd-155": 154.9226305, 
    "Gd-156": 155.9221312, 
    "Gd-157": 156.9239686, 
    "Gd-158": 157.9241123, 
    "Gd-159": 158.926397, 
    "Gd-160": 159.9270624, 
    "Gd-161": 160.9296775, 
    "Gd-162": 161.930993, 
    "Gd-163": 162.9341769, 
    "Gd-164": 163.93583, 
    "Gd-165": 164.93936, 
    "Gd-166": 165.94146, 
    "Gd-167": 166.94545, 
    "Gd-168": 167.94808, 
    "Gd-169": 168.9526, 
    "Tb-135": 134.96476, 
    "Tb-136": 135.96129, 
    "Tb-137": 136.95602, 
    "Tb-138": 137.95312, 
    "Tb-139": 138.94833, 
    "Tb-140": 139.94581, 
    "Tb-141": 140.94145, 
    "Tb-142": 141.93928, 
    "Tb-143": 142.935137, 
    "Tb-144": 143.933045, 
    "Tb-145": 144.92882, 
    "Tb-146": 145.927253, 
    "Tb-147": 146.9240548, 
    "Tb-148": 147.924282, 
    "Tb-149": 148.9232535, 
    "Tb-150": 149.9236649, 
    "Tb-151": 150.9231096, 
    "Tb-152": 151.924083, 
    "Tb-153": 152.9234424, 
    "Tb-154": 153.924685, 
    "Tb-155": 154.923511, 
    "Tb-156": 155.9247552, 
    "Tb-157": 156.924033, 
    "Tb-158": 157.9254209, 
    "Tb-159": 158.9253547, 
    "Tb-160": 159.9271756, 
    "Tb-161": 160.9275778, 
    "Tb-162": 161.929495, 
    "Tb-163": 162.9306547, 
    "Tb-164": 163.93336, 
    "Tb-165": 164.93498, 
    "Tb-166": 165.93786, 
    "Tb-167": 166.93996, 
    "Tb-168": 167.9434, 
    "Tb-169": 168.94597, 
    "Tb-170": 169.94984, 
    "Tb-171": 170.95273, 
    "Dy-138": 137.9625, 
    "Dy-139": 138.95959, 
    "Dy-140": 139.95402, 
    "Dy-141": 140.95128, 
    "Dy-142": 141.94619, 
    "Dy-143": 142.943994, 
    "Dy-144": 143.9392695, 
    "Dy-145": 144.937474, 
    "Dy-146": 145.9328445, 
    "Dy-147": 146.9310827, 
    "Dy-148": 147.927157, 
    "Dy-149": 148.927322, 
    "Dy-150": 149.9255933, 
    "Dy-151": 150.9261916, 
    "Dy-152": 151.9247253, 
    "Dy-153": 152.9257724, 
    "Dy-154": 153.9244293, 
    "Dy-155": 154.925759, 
    "Dy-156": 155.9242847, 
    "Dy-157": 156.9254707, 
    "Dy-158": 157.9244159, 
    "Dy-159": 158.925747, 
    "Dy-160": 159.9252046, 
    "Dy-161": 160.9269405, 
    "Dy-162": 161.9268056, 
    "Dy-163": 162.9287383, 
    "Dy-164": 163.9291819, 
    "Dy-165": 164.9317105, 
    "Dy-166": 165.9328139, 
    "Dy-167": 166.935661, 
    "Dy-168": 167.93713, 
    "Dy-169": 168.94031, 
    "Dy-170": 169.94239, 
    "Dy-171": 170.94612, 
    "Dy-172": 171.94846, 
    "Dy-173": 172.95283, 
    "Ho-140": 139.96859, 
    "Ho-141": 140.96311, 
    "Ho-142": 141.96001, 
    "Ho-143": 142.95486, 
    "Ho-144": 143.9521097, 
    "Ho-145": 144.9472674, 
    "Ho-146": 145.9449935, 
    "Ho-147": 146.9401423, 
    "Ho-148": 147.937744, 
    "Ho-149": 148.933803, 
    "Ho-150": 149.933498, 
    "Ho-151": 150.9316983, 
    "Ho-152": 151.931724, 
    "Ho-153": 152.9302064, 
    "Ho-154": 153.9306068, 
    "Ho-155": 154.929104, 
    "Ho-156": 155.929706, 
    "Ho-157": 156.928254, 
    "Ho-158": 157.928946, 
    "Ho-159": 158.9277197, 
    "Ho-160": 159.928737, 
    "Ho-161": 160.9278615, 
    "Ho-162": 161.9291023, 
    "Ho-163": 162.928741, 
    "Ho-164": 163.9302403, 
    "Ho-165": 164.9303288, 
    "Ho-166": 165.9322909, 
    "Ho-167": 166.9331385, 
    "Ho-168": 167.935522, 
    "Ho-169": 168.936878, 
    "Ho-170": 169.939625, 
    "Ho-171": 170.94147, 
    "Ho-172": 171.94473, 
    "Ho-173": 172.94702, 
    "Ho-174": 173.95095, 
    "Ho-175": 174.95362, 
    "Er-142": 141.9701, 
    "Er-143": 142.96662, 
    "Er-144": 143.9607, 
    "Er-145": 144.95805, 
    "Er-146": 145.9524184, 
    "Er-147": 146.949964, 
    "Er-148": 147.944735, 
    "Er-149": 148.942306, 
    "Er-150": 149.937916, 
    "Er-151": 150.937449, 
    "Er-152": 151.935057, 
    "Er-153": 152.93508, 
    "Er-154": 153.9327908, 
    "Er-155": 154.9332159, 
    "Er-156": 155.931067, 
    "Er-157": 156.931949, 
    "Er-158": 157.929893, 
    "Er-159": 158.9306918, 
    "Er-160": 159.929077, 
    "Er-161": 160.9300046, 
    "Er-162": 161.9287884, 
    "Er-163": 162.9300408, 
    "Er-164": 163.9292088, 
    "Er-165": 164.9307345, 
    "Er-166": 165.9302995, 
    "Er-167": 166.9320546, 
    "Er-168": 167.9323767, 
    "Er-169": 168.9345968, 
    "Er-170": 169.9354702, 
    "Er-171": 170.9380357, 
    "Er-172": 171.9393619, 
    "Er-173": 172.9424, 
    "Er-174": 173.94423, 
    "Er-175": 174.94777, 
    "Er-176": 175.94994, 
    "Er-177": 176.95399, 
    "Tm-144": 143.97628, 
    "Tm-145": 144.97039, 
    "Tm-146": 145.96684, 
    "Tm-147": 146.9613799, 
    "Tm-148": 147.958384, 
    "Tm-149": 148.95289, 
    "Tm-150": 149.95009, 
    "Tm-151": 150.945488, 
    "Tm-152": 151.944422, 
    "Tm-153": 152.94204, 
    "Tm-154": 153.94157, 
    "Tm-155": 154.93921, 
    "Tm-156": 155.938992, 
    "Tm-157": 156.936944, 
    "Tm-158": 157.93698, 
    "Tm-159": 158.934975, 
    "Tm-160": 159.935263, 
    "Tm-161": 160.933549, 
    "Tm-162": 161.934002, 
    "Tm-163": 162.9326592, 
    "Tm-164": 163.933544, 
    "Tm-165": 164.9324431, 
    "Tm-166": 165.933561, 
    "Tm-167": 166.9328562, 
    "Tm-168": 167.9341774, 
    "Tm-169": 168.9342179, 
    "Tm-170": 169.935806, 
    "Tm-171": 170.9364339, 
    "Tm-172": 171.9384055, 
    "Tm-173": 172.9396084, 
    "Tm-174": 173.942173, 
    "Tm-175": 174.943841, 
    "Tm-176": 175.947, 
    "Tm-177": 176.94904, 
    "Tm-178": 177.95264, 
    "Tm-179": 178.95534, 
    "Yb-148": 147.96758, 
    "Yb-149": 148.96436, 
    "Yb-150": 149.95852, 
    "Yb-151": 150.9554, 
    "Yb-152": 151.95027, 
    "Yb-153": 152.94932, 
    "Yb-154": 153.946396, 
    "Yb-155": 154.945783, 
    "Yb-156": 155.942825, 
    "Yb-157": 156.942645, 
    "Yb-158": 157.9398705, 
    "Yb-159": 158.940055, 
    "Yb-160": 159.937557, 
    "Yb-161": 160.937907, 
    "Yb-162": 161.935774, 
    "Yb-163": 162.93634, 
    "Yb-164": 163.934495, 
    "Yb-165": 164.93527, 
    "Yb-166": 165.9338747, 
    "Yb-167": 166.934953, 
    "Yb-168": 167.9338896, 
    "Yb-169": 168.9351825, 
    "Yb-170": 169.9347664, 
    "Yb-171": 170.9363302, 
    "Yb-172": 171.9363859, 
    "Yb-173": 172.9382151, 
    "Yb-174": 173.9388664, 
    "Yb-175": 174.9412808, 
    "Yb-176": 175.9425764, 
    "Yb-177": 176.9452656, 
    "Yb-178": 177.946651, 
    "Yb-179": 178.95004, 
    "Yb-180": 179.95212, 
    "Yb-181": 180.95589, 
    "Lu-150": 149.97355, 
    "Lu-151": 150.96768, 
    "Lu-152": 151.96412, 
    "Lu-153": 152.95875, 
    "Lu-154": 153.95736, 
    "Lu-155": 154.954321, 
    "Lu-156": 155.953033, 
    "Lu-157": 156.950127, 
    "Lu-158": 157.949316, 
    "Lu-159": 158.946636, 
    "Lu-160": 159.946033, 
    "Lu-161": 160.943572, 
    "Lu-162": 161.943283, 
    "Lu-163": 162.941179, 
    "Lu-164": 163.941339, 
    "Lu-165": 164.939407, 
    "Lu-166": 165.939859, 
    "Lu-167": 166.93827, 
    "Lu-168": 167.938736, 
    "Lu-169": 168.9376441, 
    "Lu-170": 169.938478, 
    "Lu-171": 170.937917, 
    "Lu-172": 171.9390891, 
    "Lu-173": 172.938934, 
    "Lu-174": 173.9403409, 
    "Lu-175": 174.9407752, 
    "Lu-176": 175.9426897, 
    "Lu-177": 176.9437615, 
    "Lu-178": 177.945958, 
    "Lu-179": 178.9473309, 
    "Lu-180": 179.949888, 
    "Lu-181": 180.95191, 
    "Lu-182": 181.95504, 
    "Lu-183": 182.957363, 
    "Lu-184": 183.96091, 
    "Lu-185": 184.96362, 
    "Hf-153": 152.97069, 
    "Hf-154": 153.96486, 
    "Hf-155": 154.96311, 
    "Hf-156": 155.95935, 
    "Hf-157": 156.95824, 
    "Hf-158": 157.954801, 
    "Hf-159": 158.953996, 
    "Hf-160": 159.950691, 
    "Hf-161": 160.950278, 
    "Hf-162": 161.9472148, 
    "Hf-163": 162.947113, 
    "Hf-164": 163.944371, 
    "Hf-165": 164.944567, 
    "Hf-166": 165.94218, 
    "Hf-167": 166.9426, 
    "Hf-168": 167.940568, 
    "Hf-169": 168.941259, 
    "Hf-170": 169.939609, 
    "Hf-171": 170.940492, 
    "Hf-172": 171.93945, 
    "Hf-173": 172.940513, 
    "Hf-174": 173.9400461, 
    "Hf-175": 174.9415092, 
    "Hf-176": 175.9414076, 
    "Hf-177": 176.9432277, 
    "Hf-178": 177.9437058, 
    "Hf-179": 178.9458232, 
    "Hf-180": 179.946557, 
    "Hf-181": 180.9491083, 
    "Hf-182": 181.9505612, 
    "Hf-183": 182.95353, 
    "Hf-184": 183.955446, 
    "Hf-185": 184.958862, 
    "Hf-186": 185.960897, 
    "Hf-187": 186.96477, 
    "Hf-188": 187.96685, 
    "Hf-189": 188.97084, 
    "Ta-155": 154.97424, 
    "Ta-156": 155.97203, 
    "Ta-157": 156.96818, 
    "Ta-158": 157.96654, 
    "Ta-159": 158.963023, 
    "Ta-160": 159.961488, 
    "Ta-161": 160.958452, 
    "Ta-162": 161.957294, 
    "Ta-163": 162.954337, 
    "Ta-164": 163.953534, 
    "Ta-165": 164.950781, 
    "Ta-166": 165.950512, 
    "Ta-167": 166.948093, 
    "Ta-168": 167.948047, 
    "Ta-169": 168.946011, 
    "Ta-170": 169.946175, 
    "Ta-171": 170.944476, 
    "Ta-172": 171.944895, 
    "Ta-173": 172.94375, 
    "Ta-174": 173.944454, 
    "Ta-175": 174.943737, 
    "Ta-176": 175.944857, 
    "Ta-177": 176.9444795, 
    "Ta-178": 177.945678, 
    "Ta-179": 178.9459366, 
    "Ta-180": 179.9474648, 
    "Ta-181": 180.9479958, 
    "Ta-182": 181.9501519, 
    "Ta-183": 182.9513726, 
    "Ta-184": 183.954008, 
    "Ta-185": 184.955559, 
    "Ta-186": 185.958551, 
    "Ta-187": 186.960386, 
    "Ta-188": 187.963916, 
    "Ta-189": 188.96583, 
    "Ta-190": 189.96939, 
    "Ta-191": 190.97156, 
    "Ta-192": 191.97514, 
    "W-157": 156.97884, 
    "W-158": 157.97456, 
    "W-159": 158.97264, 
    "W-160": 159.96846, 
    "W-161": 160.9672, 
    "W-162": 161.963499, 
    "W-163": 162.962524, 
    "W-164": 163.958961, 
    "W-165": 164.958281, 
    "W-166": 165.955031, 
    "W-167": 166.954805, 
    "W-168": 167.951806, 
    "W-169": 168.951779, 
    "W-170": 169.949232, 
    "W-171": 170.949451, 
    "W-172": 171.947292, 
    "W-173": 172.947689, 
    "W-174": 173.946079, 
    "W-175": 174.946717, 
    "W-176": 175.945634, 
    "W-177": 176.946643, 
    "W-178": 177.945883, 
    "W-179": 178.947077, 
    "W-180": 179.9467108, 
    "W-181": 180.9481978, 
    "W-182": 181.94820394, 
    "W-183": 182.95022275, 
    "W-184": 183.95093092, 
    "W-185": 184.95341897, 
    "W-186": 185.9543628, 
    "W-187": 186.9571588, 
    "W-188": 187.9584862, 
    "W-189": 188.961763, 
    "W-190": 189.963091, 
    "W-191": 190.966531, 
    "W-192": 191.96817, 
    "W-193": 192.97178, 
    "W-194": 193.97367, 
    "Re-159": 158.98418, 
    "Re-160": 159.98182, 
    "Re-161": 160.97757, 
    "Re-162": 161.97584, 
    "Re-163": 162.97208, 
    "Re-164": 163.970453, 
    "Re-165": 164.967103, 
    "Re-166": 165.965761, 
    "Re-167": 166.962595, 
    "Re-168": 167.961573, 
    "Re-169": 168.958766, 
    "Re-170": 169.95822, 
    "Re-171": 170.955716, 
    "Re-172": 171.95542, 
    "Re-173": 172.953243, 
    "Re-174": 173.953115, 
    "Re-175": 174.951381, 
    "Re-176": 175.951623, 
    "Re-177": 176.950328, 
    "Re-178": 177.950989, 
    "Re-179": 178.949989, 
    "Re-180": 179.950792, 
    "Re-181": 180.950058, 
    "Re-182": 181.95121, 
    "Re-183": 182.9508196, 
    "Re-184": 183.9525228, 
    "Re-185": 184.9529545, 
    "Re-186": 185.9549856, 
    "Re-187": 186.9557501, 
    "Re-188": 187.9581115, 
    "Re-189": 188.959226, 
    "Re-190": 189.961744, 
    "Re-191": 190.963122, 
    "Re-192": 191.966088, 
    "Re-193": 192.967541, 
    "Re-194": 193.97076, 
    "Re-195": 194.97254, 
    "Re-196": 195.9758, 
    "Re-197": 196.97799, 
    "Re-198": 197.9816, 
    "Os-161": 160.98903, 
    "Os-162": 161.98443, 
    "Os-163": 162.98241, 
    "Os-164": 163.97802, 
    "Os-165": 164.9766, 
    "Os-166": 165.972692, 
    "Os-167": 166.971549, 
    "Os-168": 167.967808, 
    "Os-169": 168.967018, 
    "Os-170": 169.963578, 
    "Os-171": 170.963174, 
    "Os-172": 171.960017, 
    "Os-173": 172.959808, 
    "Os-174": 173.957064, 
    "Os-175": 174.956945, 
    "Os-176": 175.954806, 
    "Os-177": 176.954966, 
    "Os-178": 177.953254, 
    "Os-179": 178.953817, 
    "Os-180": 179.952375, 
    "Os-181": 180.953247, 
    "Os-182": 181.95211, 
    "Os-183": 182.953125, 
    "Os-184": 183.9524885, 
    "Os-185": 184.9540417, 
    "Os-186": 185.953835, 
    "Os-187": 186.9557474, 
    "Os-188": 187.9558352, 
    "Os-189": 188.9581442, 
    "Os-190": 189.9584437, 
    "Os-191": 190.9609264, 
    "Os-192": 191.961477, 
    "Os-193": 192.9641479, 
    "Os-194": 193.9651772, 
    "Os-195": 194.968318, 
    "Os-196": 195.969641, 
    "Os-197": 196.97283, 
    "Os-198": 197.97441, 
    "Os-199": 198.97801, 
    "Os-200": 199.97984, 
    "Os-201": 200.98364, 
    "Os-202": 201.98595, 
    "Ir-164": 163.99191, 
    "Ir-165": 164.9875, 
    "Ir-166": 165.98566, 
    "Ir-167": 166.981666, 
    "Ir-168": 167.979907, 
    "Ir-169": 168.976298, 
    "Ir-170": 169.974922, 
    "Ir-171": 170.97164, 
    "Ir-172": 171.970607, 
    "Ir-173": 172.967506, 
    "Ir-174": 173.966861, 
    "Ir-175": 174.96415, 
    "Ir-176": 175.96365, 
    "Ir-177": 176.961301, 
    "Ir-178": 177.961082, 
    "Ir-179": 178.95912, 
    "Ir-180": 179.959229, 
    "Ir-181": 180.957625, 
    "Ir-182": 181.958076, 
    "Ir-183": 182.95684, 
    "Ir-184": 183.957476, 
    "Ir-185": 184.956698, 
    "Ir-186": 185.957944, 
    "Ir-187": 186.957542, 
    "Ir-188": 187.958828, 
    "Ir-189": 188.958715, 
    "Ir-190": 189.9605412, 
    "Ir-191": 190.9605893, 
    "Ir-192": 191.9626002, 
    "Ir-193": 192.9629216, 
    "Ir-194": 193.9650735, 
    "Ir-195": 194.9659747, 
    "Ir-196": 195.968397, 
    "Ir-197": 196.969655, 
    "Ir-198": 197.97228, 
    "Ir-199": 198.973805, 
    "Ir-200": 199.9768, 
    "Ir-201": 200.97864, 
    "Ir-202": 201.98199, 
    "Ir-203": 202.98423, 
    "Ir-204": 203.9896, 
    "Pt-166": 165.99486, 
    "Pt-167": 166.99269, 
    "Pt-168": 167.98813, 
    "Pt-169": 168.98657, 
    "Pt-170": 169.982496, 
    "Pt-171": 170.981245, 
    "Pt-172": 171.977351, 
    "Pt-173": 172.976443, 
    "Pt-174": 173.97282, 
    "Pt-175": 174.97241, 
    "Pt-176": 175.968938, 
    "Pt-177": 176.96847, 
    "Pt-178": 177.96565, 
    "Pt-179": 178.965359, 
    "Pt-180": 179.963032, 
    "Pt-181": 180.963098, 
    "Pt-182": 181.961172, 
    "Pt-183": 182.961597, 
    "Pt-184": 183.959915, 
    "Pt-185": 184.960614, 
    "Pt-186": 185.959351, 
    "Pt-187": 186.960617, 
    "Pt-188": 187.9593889, 
    "Pt-189": 188.960831, 
    "Pt-190": 189.9599297, 
    "Pt-191": 190.9616729, 
    "Pt-192": 191.9610387, 
    "Pt-193": 192.9629824, 
    "Pt-194": 193.9626809, 
    "Pt-195": 194.9647917, 
    "Pt-196": 195.96495209, 
    "Pt-197": 196.96734069, 
    "Pt-198": 197.9678949, 
    "Pt-199": 198.9705952, 
    "Pt-200": 199.971443, 
    "Pt-201": 200.974513, 
    "Pt-202": 201.975639, 
    "Pt-203": 202.97893, 
    "Pt-204": 203.98076, 
    "Pt-205": 204.98608, 
    "Pt-206": 205.98966, 
    "Au-169": 168.99808, 
    "Au-170": 169.99597, 
    "Au-171": 170.991876, 
    "Au-172": 171.989942, 
    "Au-173": 172.986241, 
    "Au-174": 173.984717, 
    "Au-175": 174.981304, 
    "Au-176": 175.98025, 
    "Au-177": 176.97687, 
    "Au-178": 177.976032, 
    "Au-179": 178.973174, 
    "Au-180": 179.972523, 
    "Au-181": 180.970079, 
    "Au-182": 181.969618, 
    "Au-183": 182.967591, 
    "Au-184": 183.967452, 
    "Au-185": 184.96579, 
    "Au-186": 185.965953, 
    "Au-187": 186.964543, 
    "Au-188": 187.965349, 
    "Au-189": 188.963948, 
    "Au-190": 189.964698, 
    "Au-191": 190.963702, 
    "Au-192": 191.964814, 
    "Au-193": 192.9641373, 
    "Au-194": 193.9654178, 
    "Au-195": 194.9650352, 
    "Au-196": 195.9665699, 
    "Au-197": 196.96656879, 
    "Au-198": 197.96824242, 
    "Au-199": 198.96876528, 
    "Au-200": 199.970756, 
    "Au-201": 200.9716575, 
    "Au-202": 201.973856, 
    "Au-203": 202.9751544, 
    "Au-204": 203.97783, 
    "Au-205": 204.97985, 
    "Au-206": 205.98474, 
    "Au-207": 206.9884, 
    "Au-208": 207.99345, 
    "Au-209": 208.99735, 
    "Au-210": 210.0025, 
    "Hg-171": 171.00353, 
    "Hg-172": 171.99881, 
    "Hg-173": 172.99709, 
    "Hg-174": 173.992865, 
    "Hg-175": 174.991441, 
    "Hg-176": 175.987361, 
    "Hg-177": 176.986277, 
    "Hg-178": 177.982484, 
    "Hg-179": 178.981831, 
    "Hg-180": 179.97826, 
    "Hg-181": 180.977819, 
    "Hg-182": 181.974689, 
    "Hg-183": 182.9744448, 
    "Hg-184": 183.971714, 
    "Hg-185": 184.971899, 
    "Hg-186": 185.969362, 
    "Hg-187": 186.969814, 
    "Hg-188": 187.967567, 
    "Hg-189": 188.968195, 
    "Hg-190": 189.966323, 
    "Hg-191": 190.967157, 
    "Hg-192": 191.965635, 
    "Hg-193": 192.966653, 
    "Hg-194": 193.9654491, 
    "Hg-195": 194.966721, 
    "Hg-196": 195.9658326, 
    "Hg-197": 196.9672128, 
    "Hg-198": 197.9667686, 
    "Hg-199": 198.96828064, 
    "Hg-200": 199.96832659, 
    "Hg-201": 200.97030284, 
    "Hg-202": 201.9706434, 
    "Hg-203": 202.9728728, 
    "Hg-204": 203.97349398, 
    "Hg-205": 204.9760734, 
    "Hg-206": 205.977514, 
    "Hg-207": 206.9823, 
    "Hg-208": 207.985759, 
    "Hg-209": 208.99072, 
    "Hg-210": 209.99424, 
    "Hg-211": 210.99933, 
    "Hg-212": 212.00296, 
    "Hg-213": 213.00823, 
    "Hg-214": 214.012, 
    "Hg-215": 215.0174, 
    "Hg-216": 216.02132, 
    "Tl-176": 176.000624, 
    "Tl-177": 176.996431, 
    "Tl-178": 177.99485, 
    "Tl-179": 178.991111, 
    "Tl-180": 179.990057, 
    "Tl-181": 180.98626, 
    "Tl-182": 181.985713, 
    "Tl-183": 182.982193, 
    "Tl-184": 183.981886, 
    "Tl-185": 184.978789, 
    "Tl-186": 185.978651, 
    "Tl-187": 186.9759063, 
    "Tl-188": 187.976021, 
    "Tl-189": 188.973588, 
    "Tl-190": 189.973828, 
    "Tl-191": 190.9717842, 
    "Tl-192": 191.972225, 
    "Tl-193": 192.970502, 
    "Tl-194": 193.971081, 
    "Tl-195": 194.969774, 
    "Tl-196": 195.970481, 
    "Tl-197": 196.969576, 
    "Tl-198": 197.970483, 
    "Tl-199": 198.969877, 
    "Tl-200": 199.9709633, 
    "Tl-201": 200.970822, 
    "Tl-202": 201.972102, 
    "Tl-203": 202.9723446, 
    "Tl-204": 203.9738639, 
    "Tl-205": 204.9744278, 
    "Tl-206": 205.9761106, 
    "Tl-207": 206.9774197, 
    "Tl-208": 207.982019, 
    "Tl-209": 208.9853594, 
    "Tl-210": 209.990074, 
    "Tl-211": 210.993475, 
    "Tl-212": 211.99834, 
    "Tl-213": 213.001915, 
    "Tl-214": 214.00694, 
    "Tl-215": 215.01064, 
    "Tl-216": 216.0158, 
    "Tl-217": 217.01966, 
    "Tl-218": 218.02479, 
    "Pb-178": 178.003831, 
    "Pb-179": 179.002201, 
    "Pb-180": 179.997928, 
    "Pb-181": 180.996653, 
    "Pb-182": 181.992672, 
    "Pb-183": 182.991872, 
    "Pb-184": 183.988136, 
    "Pb-185": 184.98761, 
    "Pb-186": 185.984238, 
    "Pb-187": 186.9839109, 
    "Pb-188": 187.980875, 
    "Pb-189": 188.980807, 
    "Pb-190": 189.978082, 
    "Pb-191": 190.978276, 
    "Pb-192": 191.975775, 
    "Pb-193": 192.976173, 
    "Pb-194": 193.974012, 
    "Pb-195": 194.974543, 
    "Pb-196": 195.972774, 
    "Pb-197": 196.9734312, 
    "Pb-198": 197.972034, 
    "Pb-199": 198.972913, 
    "Pb-200": 199.971819, 
    "Pb-201": 200.972883, 
    "Pb-202": 201.972152, 
    "Pb-203": 202.9733911, 
    "Pb-204": 203.973044, 
    "Pb-205": 204.9744822, 
    "Pb-206": 205.9744657, 
    "Pb-207": 206.9758973, 
    "Pb-208": 207.9766525, 
    "Pb-209": 208.9810905, 
    "Pb-210": 209.9841889, 
    "Pb-211": 210.9887371, 
    "Pb-212": 211.9918977, 
    "Pb-213": 212.9965629, 
    "Pb-214": 213.9998059, 
    "Pb-215": 215.00474, 
    "Pb-216": 216.00803, 
    "Pb-217": 217.01314, 
    "Pb-218": 218.01659, 
    "Pb-219": 219.02177, 
    "Pb-220": 220.02541, 
    "Bi-184": 184.001275, 
    "Bi-185": 184.9976, 
    "Bi-186": 185.996644, 
    "Bi-187": 186.993147, 
    "Bi-188": 187.992287, 
    "Bi-189": 188.989195, 
    "Bi-190": 189.988622, 
    "Bi-191": 190.9857866, 
    "Bi-192": 191.985469, 
    "Bi-193": 192.98296, 
    "Bi-194": 193.982785, 
    "Bi-195": 194.9806488, 
    "Bi-196": 195.980667, 
    "Bi-197": 196.9788651, 
    "Bi-198": 197.979206, 
    "Bi-199": 198.977673, 
    "Bi-200": 199.978131, 
    "Bi-201": 200.97701, 
    "Bi-202": 201.977734, 
    "Bi-203": 202.976893, 
    "Bi-204": 203.9778361, 
    "Bi-205": 204.9773867, 
    "Bi-206": 205.9784993, 
    "Bi-207": 206.978471, 
    "Bi-208": 207.9797425, 
    "Bi-209": 208.9803991, 
    "Bi-210": 209.9841207, 
    "Bi-211": 210.9872697, 
    "Bi-212": 211.991286, 
    "Bi-213": 212.9943851, 
    "Bi-214": 213.998712, 
    "Bi-215": 215.00177, 
    "Bi-216": 216.006306, 
    "Bi-217": 217.009372, 
    "Bi-218": 218.014188, 
    "Bi-219": 219.01748, 
    "Bi-220": 220.02235, 
    "Bi-221": 221.02587, 
    "Bi-222": 222.03078, 
    "Bi-223": 223.0345, 
    "Bi-224": 224.03947, 
    "Po-186": 186.004393, 
    "Po-187": 187.003041, 
    "Po-188": 187.999416, 
    "Po-189": 188.998473, 
    "Po-190": 189.995101, 
    "Po-191": 190.9945585, 
    "Po-192": 191.991336, 
    "Po-193": 192.991026, 
    "Po-194": 193.988186, 
    "Po-195": 194.988126, 
    "Po-196": 195.985526, 
    "Po-197": 196.98566, 
    "Po-198": 197.983389, 
    "Po-199": 198.983667, 
    "Po-200": 199.981799, 
    "Po-201": 200.9822598, 
    "Po-202": 201.980758, 
    "Po-203": 202.9814161, 
    "Po-204": 203.98031, 
    "Po-205": 204.981203, 
    "Po-206": 205.980474, 
    "Po-207": 206.9815938, 
    "Po-208": 207.9812461, 
    "Po-209": 208.9824308, 
    "Po-210": 209.9828741, 
    "Po-211": 210.9866536, 
    "Po-212": 211.9888684, 
    "Po-213": 212.9928576, 
    "Po-214": 213.9952017, 
    "Po-215": 214.9994201, 
    "Po-216": 216.0019152, 
    "Po-217": 217.0063182, 
    "Po-218": 218.0089735, 
    "Po-219": 219.013614, 
    "Po-220": 220.016386, 
    "Po-221": 221.021228, 
    "Po-222": 222.02414, 
    "Po-223": 223.02907, 
    "Po-224": 224.03211, 
    "Po-225": 225.03707, 
    "Po-226": 226.04031, 
    "Po-227": 227.04539, 
    "At-191": 191.004148, 
    "At-192": 192.003152, 
    "At-193": 192.999927, 
    "At-194": 193.999236, 
    "At-195": 194.9962685, 
    "At-196": 195.9958, 
    "At-197": 196.993189, 
    "At-198": 197.992784, 
    "At-199": 198.9905277, 
    "At-200": 199.990351, 
    "At-201": 200.9884171, 
    "At-202": 201.98863, 
    "At-203": 202.986943, 
    "At-204": 203.987251, 
    "At-205": 204.986076, 
    "At-206": 205.986657, 
    "At-207": 206.9858, 
    "At-208": 207.9866133, 
    "At-209": 208.9861702, 
    "At-210": 209.9871479, 
    "At-211": 210.9874966, 
    "At-212": 211.9907377, 
    "At-213": 212.992937, 
    "At-214": 213.9963721, 
    "At-215": 214.9986528, 
    "At-216": 216.0024236, 
    "At-217": 217.0047192, 
    "At-218": 218.008695, 
    "At-219": 219.0111618, 
    "At-220": 220.015433, 
    "At-221": 221.018017, 
    "At-222": 222.022494, 
    "At-223": 223.025151, 
    "At-224": 224.029749, 
    "At-225": 225.03263, 
    "At-226": 226.03716, 
    "At-227": 227.04024, 
    "At-228": 228.04475, 
    "At-229": 229.04812, 
    "Rn-193": 193.009708, 
    "Rn-194": 194.006144, 
    "Rn-195": 195.005422, 
    "Rn-196": 196.002116, 
    "Rn-197": 197.001585, 
    "Rn-198": 197.998679, 
    "Rn-199": 198.99839, 
    "Rn-200": 199.99569, 
    "Rn-201": 200.995628, 
    "Rn-202": 201.993264, 
    "Rn-203": 202.993388, 
    "Rn-204": 203.99143, 
    "Rn-205": 204.991719, 
    "Rn-206": 205.990214, 
    "Rn-207": 206.9907303, 
    "Rn-208": 207.989635, 
    "Rn-209": 208.990415, 
    "Rn-210": 209.9896891, 
    "Rn-211": 210.9906011, 
    "Rn-212": 211.9907039, 
    "Rn-213": 212.9938831, 
    "Rn-214": 213.995363, 
    "Rn-215": 214.9987459, 
    "Rn-216": 216.0002719, 
    "Rn-217": 217.003928, 
    "Rn-218": 218.0056016, 
    "Rn-219": 219.0094804, 
    "Rn-220": 220.0113941, 
    "Rn-221": 221.0155371, 
    "Rn-222": 222.0175782, 
    "Rn-223": 223.0218893, 
    "Rn-224": 224.024096, 
    "Rn-225": 225.028486, 
    "Rn-226": 226.030861, 
    "Rn-227": 227.035304, 
    "Rn-228": 228.037835, 
    "Rn-229": 229.042257, 
    "Rn-230": 230.04514, 
    "Rn-231": 231.04987, 
    "Fr-199": 199.007259, 
    "Fr-200": 200.006586, 
    "Fr-201": 201.003867, 
    "Fr-202": 202.00332, 
    "Fr-203": 203.0009407, 
    "Fr-204": 204.000652, 
    "Fr-205": 204.9985939, 
    "Fr-206": 205.998666, 
    "Fr-207": 206.996946, 
    "Fr-208": 207.997138, 
    "Fr-209": 208.995955, 
    "Fr-210": 209.996422, 
    "Fr-211": 210.995556, 
    "Fr-212": 211.9962257, 
    "Fr-213": 212.996186, 
    "Fr-214": 213.9989713, 
    "Fr-215": 215.0003418, 
    "Fr-216": 216.0031899, 
    "Fr-217": 217.0046323, 
    "Fr-218": 218.0075787, 
    "Fr-219": 219.0092524, 
    "Fr-220": 220.0123277, 
    "Fr-221": 221.0142552, 
    "Fr-222": 222.017552, 
    "Fr-223": 223.019736, 
    "Fr-224": 224.023398, 
    "Fr-225": 225.025573, 
    "Fr-226": 226.029566, 
    "Fr-227": 227.031869, 
    "Fr-228": 228.035823, 
    "Fr-229": 229.038298, 
    "Fr-230": 230.042416, 
    "Fr-231": 231.045158, 
    "Fr-232": 232.04937, 
    "Fr-233": 233.05264, 
    "Ra-201": 201.01271, 
    "Ra-202": 202.00976, 
    "Ra-203": 203.009304, 
    "Ra-204": 204.006492, 
    "Ra-205": 205.006268, 
    "Ra-206": 206.003828, 
    "Ra-207": 207.003799, 
    "Ra-208": 208.001841, 
    "Ra-209": 209.00199, 
    "Ra-210": 210.000494, 
    "Ra-211": 211.0008932, 
    "Ra-212": 211.999787, 
    "Ra-213": 213.000384, 
    "Ra-214": 214.0000997, 
    "Ra-215": 215.0027204, 
    "Ra-216": 216.0035334, 
    "Ra-217": 217.0063207, 
    "Ra-218": 218.007141, 
    "Ra-219": 219.0100855, 
    "Ra-220": 220.0110259, 
    "Ra-221": 221.0139177, 
    "Ra-222": 222.0153748, 
    "Ra-223": 223.0185023, 
    "Ra-224": 224.020212, 
    "Ra-225": 225.0236119, 
    "Ra-226": 226.0254103, 
    "Ra-227": 227.0291783, 
    "Ra-228": 228.0310707, 
    "Ra-229": 229.034942, 
    "Ra-230": 230.037055, 
    "Ra-231": 231.041027, 
    "Ra-232": 232.0434753, 
    "Ra-233": 233.047582, 
    "Ra-234": 234.050342, 
    "Ra-235": 235.05497, 
    "Ac-206": 206.014452, 
    "Ac-207": 207.011966, 
    "Ac-208": 208.01155, 
    "Ac-209": 209.009495, 
    "Ac-210": 210.009436, 
    "Ac-211": 211.007732, 
    "Ac-212": 212.007813, 
    "Ac-213": 213.006609, 
    "Ac-214": 214.006918, 
    "Ac-215": 215.006475, 
    "Ac-216": 216.008743, 
    "Ac-217": 217.009344, 
    "Ac-218": 218.011642, 
    "Ac-219": 219.012421, 
    "Ac-220": 220.0147549, 
    "Ac-221": 221.015592, 
    "Ac-222": 222.0178442, 
    "Ac-223": 223.0191377, 
    "Ac-224": 224.0217232, 
    "Ac-225": 225.02323, 
    "Ac-226": 226.0260984, 
    "Ac-227": 227.0277523, 
    "Ac-228": 228.0310215, 
    "Ac-229": 229.032956, 
    "Ac-230": 230.036327, 
    "Ac-231": 231.038393, 
    "Ac-232": 232.042034, 
    "Ac-233": 233.044346, 
    "Ac-234": 234.048139, 
    "Ac-235": 235.05084, 
    "Ac-236": 236.054988, 
    "Ac-237": 237.05827, 
    "Th-208": 208.0179, 
    "Th-209": 209.017753, 
    "Th-210": 210.015094, 
    "Th-211": 211.014929, 
    "Th-212": 212.012988, 
    "Th-213": 213.013009, 
    "Th-214": 214.0115, 
    "Th-215": 215.0117248, 
    "Th-216": 216.011056, 
    "Th-217": 217.013117, 
    "Th-218": 218.013276, 
    "Th-219": 219.015537, 
    "Th-220": 220.015748, 
    "Th-221": 221.018184, 
    "Th-222": 222.018469, 
    "Th-223": 223.0208119, 
    "Th-224": 224.021464, 
    "Th-225": 225.0239514, 
    "Th-226": 226.0249034, 
    "Th-227": 227.0277042, 
    "Th-228": 228.0287413, 
    "Th-229": 229.0317627, 
    "Th-230": 230.0331341, 
    "Th-231": 231.0363046, 
    "Th-232": 232.0380558, 
    "Th-233": 233.0415823, 
    "Th-234": 234.0436014, 
    "Th-235": 235.047255, 
    "Th-236": 236.049657, 
    "Th-237": 237.053629, 
    "Th-238": 238.0565, 
    "Th-239": 239.06077, 
    "Pa-212": 212.023203, 
    "Pa-213": 213.021109, 
    "Pa-214": 214.020918, 
    "Pa-215": 215.019183, 
    "Pa-216": 216.019109, 
    "Pa-217": 217.018325, 
    "Pa-218": 218.020059, 
    "Pa-219": 219.019904, 
    "Pa-220": 220.021705, 
    "Pa-221": 221.021875, 
    "Pa-222": 222.023784, 
    "Pa-223": 223.023963, 
    "Pa-224": 224.0256176, 
    "Pa-225": 225.026131, 
    "Pa-226": 226.027948, 
    "Pa-227": 227.0288054, 
    "Pa-228": 228.0310517, 
    "Pa-229": 229.0320972, 
    "Pa-230": 230.034541, 
    "Pa-231": 231.0358842, 
    "Pa-232": 232.0385917, 
    "Pa-233": 233.0402472, 
    "Pa-234": 234.0433072, 
    "Pa-235": 235.045399, 
    "Pa-236": 236.048668, 
    "Pa-237": 237.051023, 
    "Pa-238": 238.054637, 
    "Pa-239": 239.05726, 
    "Pa-240": 240.06098, 
    "Pa-241": 241.06408, 
    "U-217": 217.02466, 
    "U-218": 218.023523, 
    "U-219": 219.024999, 
    "U-220": 220.02462, 
    "U-221": 221.02628, 
    "U-222": 222.026, 
    "U-223": 223.027739, 
    "U-224": 224.027605, 
    "U-225": 225.029391, 
    "U-226": 226.029339, 
    "U-227": 227.031157, 
    "U-228": 228.031371, 
    "U-229": 229.0335063, 
    "U-230": 230.0339401, 
    "U-231": 231.0362939, 
    "U-232": 232.0371563, 
    "U-233": 233.0396355, 
    "U-234": 234.0409523, 
    "U-235": 235.0439301, 
    "U-236": 236.0455682, 
    "U-237": 237.0487304, 
    "U-238": 238.0507884, 
    "U-239": 239.0542935, 
    "U-240": 240.0565934, 
    "U-241": 241.06033, 
    "U-242": 242.06293, 
    "U-243": 243.06699, 
    "Np-219": 219.03143, 
    "Np-220": 220.03254, 
    "Np-221": 221.03204, 
    "Np-222": 222.0333, 
    "Np-223": 223.03285, 
    "Np-224": 224.03422, 
    "Np-225": 225.033911, 
    "Np-226": 226.035188, 
    "Np-227": 227.034957, 
    "Np-228": 228.036067, 
    "Np-229": 229.036264, 
    "Np-230": 230.037828, 
    "Np-231": 231.038245, 
    "Np-232": 232.04011, 
    "Np-233": 233.040741, 
    "Np-234": 234.0428953, 
    "Np-235": 235.0440635, 
    "Np-236": 236.04657, 
    "Np-237": 237.0481736, 
    "Np-238": 238.0509466, 
    "Np-239": 239.0529392, 
    "Np-240": 240.056165, 
    "Np-241": 241.058253, 
    "Np-242": 242.06164, 
    "Np-243": 243.06428, 
    "Np-244": 244.06785, 
    "Np-245": 245.0708, 
    "Pu-228": 228.038732, 
    "Pu-229": 229.040144, 
    "Pu-230": 230.03965, 
    "Pu-231": 231.041102, 
    "Pu-232": 232.041185, 
    "Pu-233": 233.042998, 
    "Pu-234": 234.0433174, 
    "Pu-235": 235.045286, 
    "Pu-236": 236.0460581, 
    "Pu-237": 237.0484098, 
    "Pu-238": 238.0495601, 
    "Pu-239": 239.0521636, 
    "Pu-240": 240.0538138, 
    "Pu-241": 241.0568517, 
    "Pu-242": 242.0587428, 
    "Pu-243": 243.0620036, 
    "Pu-244": 244.0642053, 
    "Pu-245": 245.067826, 
    "Pu-246": 246.070205, 
    "Pu-247": 247.07419, 
    "Am-230": 230.04609, 
    "Am-231": 231.04556, 
    "Am-232": 232.04645, 
    "Am-233": 233.04644, 
    "Am-234": 234.04773, 
    "Am-235": 235.047908, 
    "Am-236": 236.04943, 
    "Am-237": 237.049996, 
    "Am-238": 238.051985, 
    "Am-239": 239.0530247, 
    "Am-240": 240.0553, 
    "Am-241": 241.0568293, 
    "Am-242": 242.0595494, 
    "Am-243": 243.0613813, 
    "Am-244": 244.0642851, 
    "Am-245": 245.0664548, 
    "Am-246": 246.069775, 
    "Am-247": 247.07209, 
    "Am-248": 248.07575, 
    "Am-249": 249.07848, 
    "Cm-232": 232.04982, 
    "Cm-233": 233.05077, 
    "Cm-234": 234.05016, 
    "Cm-235": 235.05154, 
    "Cm-236": 236.051374, 
    "Cm-237": 237.052869, 
    "Cm-238": 238.053081, 
    "Cm-239": 239.05491, 
    "Cm-240": 240.0555297, 
    "Cm-241": 241.0576532, 
    "Cm-242": 242.058836, 
    "Cm-243": 243.0613893, 
    "Cm-244": 244.0627528, 
    "Cm-245": 245.0654915, 
    "Cm-246": 246.0672238, 
    "Cm-247": 247.0703541, 
    "Cm-248": 248.0723499, 
    "Cm-249": 249.0759548, 
    "Cm-250": 250.078358, 
    "Cm-251": 251.082286, 
    "Cm-252": 252.08487, 
    "Bk-234": 234.05727, 
    "Bk-235": 235.05658, 
    "Bk-236": 236.05748, 
    "Bk-237": 237.0571, 
    "Bk-238": 238.0582, 
    "Bk-239": 239.05824, 
    "Bk-240": 240.05976, 
    "Bk-241": 241.06016, 
    "Bk-242": 242.06198, 
    "Bk-243": 243.0630078, 
    "Bk-244": 244.065181, 
    "Bk-245": 245.0663618, 
    "Bk-246": 246.068673, 
    "Bk-247": 247.0703073, 
    "Bk-248": 248.073088, 
    "Bk-249": 249.0749877, 
    "Bk-250": 250.0783167, 
    "Bk-251": 251.080762, 
    "Bk-252": 252.08431, 
    "Bk-253": 253.08688, 
    "Bk-254": 254.0906, 
    "Cf-237": 237.062198, 
    "Cf-238": 238.06149, 
    "Cf-239": 239.06253, 
    "Cf-240": 240.062256, 
    "Cf-241": 241.06369, 
    "Cf-242": 242.063754, 
    "Cf-243": 243.06548, 
    "Cf-244": 244.0660008, 
    "Cf-245": 245.0680487, 
    "Cf-246": 246.0688055, 
    "Cf-247": 247.070965, 
    "Cf-248": 248.0721851, 
    "Cf-249": 249.0748539, 
    "Cf-250": 250.0764062, 
    "Cf-251": 251.0795886, 
    "Cf-252": 252.0816272, 
    "Cf-253": 253.0851345, 
    "Cf-254": 254.087324, 
    "Cf-255": 255.09105, 
    "Cf-256": 256.09344, 
    "Es-239": 239.06823, 
    "Es-240": 240.06892, 
    "Es-241": 241.06856, 
    "Es-242": 242.06957, 
    "Es-243": 243.06951, 
    "Es-244": 244.07088, 
    "Es-245": 245.07125, 
    "Es-246": 246.0729, 
    "Es-247": 247.073622, 
    "Es-248": 248.075471, 
    "Es-249": 249.076411, 
    "Es-250": 250.07861, 
    "Es-251": 251.0799936, 
    "Es-252": 252.08298, 
    "Es-253": 253.0848257, 
    "Es-254": 254.0880222, 
    "Es-255": 255.090275, 
    "Es-256": 256.0936, 
    "Es-257": 257.09598, 
    "Es-258": 258.09952, 
    "Fm-241": 241.07421, 
    "Fm-242": 242.07343, 
    "Fm-243": 243.07446, 
    "Fm-244": 244.07404, 
    "Fm-245": 245.07535, 
    "Fm-246": 246.07535, 
    "Fm-247": 247.07694, 
    "Fm-248": 248.0771865, 
    "Fm-249": 249.0789275, 
    "Fm-250": 250.079521, 
    "Fm-251": 251.08154, 
    "Fm-252": 252.0824671, 
    "Fm-253": 253.0851846, 
    "Fm-254": 254.0868544, 
    "Fm-255": 255.089964, 
    "Fm-256": 256.0917745, 
    "Fm-257": 257.0951061, 
    "Fm-258": 258.09708, 
    "Fm-259": 259.1006, 
    "Fm-260": 260.10281, 
    "Md-245": 245.08081, 
    "Md-246": 246.08171, 
    "Md-247": 247.08152, 
    "Md-248": 248.08282, 
    "Md-249": 249.08291, 
    "Md-250": 250.08441, 
    "Md-251": 251.084774, 
    "Md-252": 252.08643, 
    "Md-253": 253.087144, 
    "Md-254": 254.08959, 
    "Md-255": 255.0910841, 
    "Md-256": 256.09389, 
    "Md-257": 257.0955424, 
    "Md-258": 258.0984315, 
    "Md-259": 259.10051, 
    "Md-260": 260.10365, 
    "Md-261": 261.10583, 
    "Md-262": 262.1091, 
    "No-248": 248.08655, 
    "No-249": 249.0878, 
    "No-250": 250.08756, 
    "No-251": 251.08894, 
    "No-252": 252.088967, 
    "No-253": 253.0905641, 
    "No-254": 254.090956, 
    "No-255": 255.093191, 
    "No-256": 256.0942829, 
    "No-257": 257.0968878, 
    "No-258": 258.09821, 
    "No-259": 259.10103, 
    "No-260": 260.10264, 
    "No-261": 261.1057, 
    "No-262": 262.10746, 
    "No-263": 263.11071, 
    "No-264": 264.11273, 
    "Lr-251": 251.09418, 
    "Lr-252": 252.09526, 
    "Lr-253": 253.09509, 
    "Lr-254": 254.09648, 
    "Lr-255": 255.096562, 
    "Lr-256": 256.098494, 
    "Lr-257": 257.099418, 
    "Lr-258": 258.10176, 
    "Lr-259": 259.102902, 
    "Lr-260": 260.1055, 
    "Lr-261": 261.10688, 
    "Lr-262": 262.10961, 
    "Lr-263": 263.11136, 
    "Lr-264": 264.1142, 
    "Lr-265": 265.11619, 
    "Lr-266": 266.11983, 
    "Rf-253": 253.10044, 
    "Rf-254": 254.10005, 
    "Rf-255": 255.10127, 
    "Rf-256": 256.101152, 
    "Rf-257": 257.102918, 
    "Rf-258": 258.103428, 
    "Rf-259": 259.105596, 
    "Rf-260": 260.10644, 
    "Rf-261": 261.108773, 
    "Rf-262": 262.10992, 
    "Rf-263": 263.11249, 
    "Rf-264": 264.11388, 
    "Rf-265": 265.11668, 
    "Rf-266": 266.11817, 
    "Rf-267": 267.12179, 
    "Rf-268": 268.12397, 
    "Db-255": 255.10707, 
    "Db-256": 256.10789, 
    "Db-257": 257.10758, 
    "Db-258": 258.10928, 
    "Db-259": 259.109492, 
    "Db-260": 260.1113, 
    "Db-261": 261.11192, 
    "Db-262": 262.11407, 
    "Db-263": 263.11499, 
    "Db-264": 264.11741, 
    "Db-265": 265.11861, 
    "Db-266": 266.12103, 
    "Db-267": 267.12247, 
    "Db-268": 268.12567, 
    "Db-269": 269.12791, 
    "Db-270": 270.13136, 
    "Sg-258": 258.11298, 
    "Sg-259": 259.1144, 
    "Sg-260": 260.114384, 
    "Sg-261": 261.115949, 
    "Sg-262": 262.116337, 
    "Sg-263": 263.11829, 
    "Sg-264": 264.11893, 
    "Sg-265": 265.12109, 
    "Sg-266": 266.12198, 
    "Sg-267": 267.12436, 
    "Sg-268": 268.12539, 
    "Sg-269": 269.12863, 
    "Sg-270": 270.13043, 
    "Sg-271": 271.13393, 
    "Sg-272": 272.13589, 
    "Sg-273": 273.13958, 
    "Bh-260": 260.12166, 
    "Bh-261": 261.12145, 
    "Bh-262": 262.12297, 
    "Bh-263": 263.12292, 
    "Bh-264": 264.12459, 
    "Bh-265": 265.12491, 
    "Bh-266": 266.12679, 
    "Bh-267": 267.1275, 
    "Bh-268": 268.12969, 
    "Bh-269": 269.13042, 
    "Bh-270": 270.13336, 
    "Bh-271": 271.13526, 
    "Bh-272": 272.13826, 
    "Bh-273": 273.14024, 
    "Bh-274": 274.14355, 
    "Bh-275": 275.14567, 
    "Hs-263": 263.12852, 
    "Hs-264": 264.128357, 
    "Hs-265": 265.129793, 
    "Hs-266": 266.130046, 
    "Hs-267": 267.13167, 
    "Hs-268": 268.13186, 
    "Hs-269": 269.13375, 
    "Hs-270": 270.13429, 
    "Hs-271": 271.13717, 
    "Hs-272": 272.1385, 
    "Hs-273": 273.14168, 
    "Hs-274": 274.1433, 
    "Hs-275": 275.14667, 
    "Hs-276": 276.14846, 
    "Hs-277": 277.1519, 
    "Mt-265": 265.136, 
    "Mt-266": 266.13737, 
    "Mt-267": 267.13719, 
    "Mt-268": 268.13865, 
    "Mt-269": 269.13882, 
    "Mt-270": 270.14033, 
    "Mt-271": 271.14074, 
    "Mt-272": 272.14341, 
    "Mt-273": 273.1444, 
    "Mt-274": 274.14724, 
    "Mt-275": 275.14882, 
    "Mt-276": 276.15159, 
    "Mt-277": 277.15327, 
    "Mt-278": 278.15631, 
    "Mt-279": 279.15808, 
    "Ds-267": 267.14377, 
    "Ds-268": 268.14348, 
    "Ds-269": 269.144752, 
    "Ds-270": 270.144584, 
    "Ds-271": 271.14595, 
    "Ds-272": 272.14602, 
    "Ds-273": 273.14856, 
    "Ds-274": 274.14941, 
    "Ds-275": 275.15203, 
    "Ds-276": 276.15303, 
    "Ds-277": 277.15591, 
    "Ds-278": 278.15704, 
    "Ds-279": 279.1601, 
    "Ds-280": 280.16131, 
    "Ds-281": 281.16451, 
    "Rg-272": 272.15327, 
    "Rg-273": 273.15313, 
    "Rg-274": 274.15525, 
    "Rg-275": 275.15594, 
    "Rg-276": 276.15833, 
    "Rg-277": 277.15907, 
    "Rg-278": 278.16149, 
    "Rg-279": 279.16272, 
    "Rg-280": 280.16514, 
    "Rg-281": 281.16636, 
    "Rg-282": 282.16912, 
    "Rg-283": 283.17054, 
    "Cn-276": 276.16141, 
    "Cn-277": 277.16364, 
    "Cn-278": 278.16416, 
    "Cn-279": 279.16654, 
    "Cn-280": 280.16715, 
    "Cn-281": 281.16975, 
    "Cn-282": 282.1705, 
    "Cn-283": 283.17327, 
    "Cn-284": 284.17416, 
    "Cn-285": 285.17712, 
    "Uut-278": 278.17058, 
    "Uut-279": 279.17095, 
    "Uut-280": 280.17293, 
    "Uut-281": 281.17348, 
    "Uut-282": 282.17567, 
    "Uut-283": 283.17657, 
    "Uut-284": 284.17873, 
    "Uut-285": 285.17973, 
    "Uut-286": 286.18221, 
    "Uut-287": 287.18339, 
    "Fl-285": 285.18364, 
    "Fl-286": 286.18423, 
    "Fl-287": 287.18678, 
    "Fl-288": 288.18757, 
    "Fl-289": 289.19042, 
    "Uup-287": 287.1907, 
    "Uup-288": 288.19274, 
    "Uup-289": 289.19363, 
    "Uup-290": 290.19598, 
    "Uup-291": 291.19707, 
    "Lv-289": 289.19816, 
    "Lv-290": 290.19864, 
    "Lv-291": 291.20108, 
    "Lv-292": 292.20174, 
    "Lv-293": 293.20449, 
    "Uus-291": 291.20553, 
    "Uus-292": 292.20746, 
    "Uus-293": 293.20824, 
    "Uus-294": 294.21046, 
    "Uuo-293": 293.21356, 
    "Uuo-294": 294.21392, 
    "Uuo-295": 295.21624
}

def atomic_number(symbol):
    """
    Return the corresponding atomic number for a given atomic symbol.
    
    Parameters
    ----------
    symbol : str
        An atomic symbol.
    
    Return
    ------
    int
        The corresponding atomic number.
    """
    return atomic_symbols.index(symbol) + 1

def atomic_symbol(number):
    """
    Return the corresponding atomic symbol for a given atomic number.
    
    Parameters
    ----------
    number : int
        An atomic number.
    
    Return
    ------
    int
        The corresponding atomic symbol.
    """
    return atomic_symbols[number-1]

def atomic_mass(term):
    """
    Get the atomic mass of an element or isotope.  Isotopes are specified
    using symbols followed by -#, where # is the mass number (eg. 'He-3').
    Deuterium and tritium can alternatively be specified using D and T
    respectively.  Values obtained from NIST reference database:
    http://www.nist.gov/pml/data/comp.cfm
    
    Parameters
    ----------
    term : str or int
        The atomic number or atomic/isotope symbol to retrieve the mass for.
        
    Returns
    -------
    float
        The average standard atomic weight of an element or the relative
        atomic mass of an isotope.
    """
    
    try:
        # Try converting term to an int
        term = int(term)
    except:
        pass
    else:
        # Convert int terms from atomic numbers to symbols
        term = atomic_symbol(term)
    
    try:
        # Try fetching atomic mass using term
        return atomic_masses[term]
    except:
        # Error if element symbol exists but has no standard weight
        if term in atomic_symbols:
            raise ValueError('No standard weight for element ' + term + '. Specify an isotope instead.')
        # Error for unknown element/isotope symbol
        else:
            raise KeyError('Unknown element/isotope symbol: ' + term)